@@ -130,11 +130,16 @@ GCG_HISTORY_add (enum GCG_HISTORY_Type type,
   gtk_list_store_insert_with_values (history_liststore,
                                      &iter,
                                      -1,
-                                     HISTORY_LS_TIME, ts,
-                                     HISTORY_LS_EVENT, event,
-                                     HISTORY_LS_CONTACT, contact_name,
-                                     HISTORY_LS_NUMBER, call_number,
-                                     HISTORY_LS_TIME_ORDER, (guint64) now.abs_value_us,
+                                     HISTORY_LS_TIME,
+                                     ts,
+                                     HISTORY_LS_EVENT,
+                                     event,
+                                     HISTORY_LS_CONTACT,
+                                     contact_name,
+                                     HISTORY_LS_NUMBER,
+                                     call_number,
+                                     HISTORY_LS_TIME_ORDER,
+                                     (guint64) now.abs_value_us,
                                      -1);
 }
 
@@ -145,9 +150,8 @@ GCG_HISTORY_add (enum GCG_HISTORY_Type type,
 void
 GCG_HISTORY_init ()
 {
-  history_liststore =
-      GTK_LIST_STORE (GCG_get_main_window_object
-                      ("gnunet_conversation_gtk_history_liststore"));
+  history_liststore = GTK_LIST_STORE (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_history_liststore"));
 }
 
 /* end of gnunet-conversation-gtk_history.c */
