@@ -226,7 +226,6 @@ struct IncomingCall
    * State for this call.
    */
   enum InCallState state;
-
 };
 
 
@@ -260,7 +259,6 @@ struct OutgoingCall
    * State for this call.
    */
   enum OutCallState state;
-
 };
 
 
@@ -369,17 +367,17 @@ in_call_state_to_string (enum InCallState is)
   switch (is)
   {
   case IN_STATE_NONE:
-    return _("none");
+    return _ ("none");
   case IN_STATE_RINGING:
-    return _("ringing");
+    return _ ("ringing");
   case IN_STATE_CONNECTED:
-    return _("connected");
+    return _ ("connected");
   case IN_STATE_SUSPENDED_LOCAL:
-    return _("suspended");
+    return _ ("suspended");
   case IN_STATE_SUSPENDED_REMOTE:
-    return _("on hold");
+    return _ ("on hold");
   case IN_STATE_SUSPENDED_BOTH:
-    return _("suspended and on hold");
+    return _ ("suspended and on hold");
   }
   return NULL;
 }
@@ -397,19 +395,19 @@ out_call_state_to_string (enum OutCallState os)
   switch (os)
   {
   case OUT_STATE_NONE:
-    return _("none");
+    return _ ("none");
   case OUT_STATE_RESOLVING:
-    return _("resolving");
+    return _ ("resolving");
   case OUT_STATE_RINGING:
-    return _("calling");
+    return _ ("calling");
   case OUT_STATE_CONNECTED:
-    return _("connected");
+    return _ ("connected");
   case OUT_STATE_SUSPENDED_LOCAL:
-    return _("suspended");
+    return _ ("suspended");
   case OUT_STATE_SUSPENDED_REMOTE:
-    return _("on hold");
+    return _ ("on hold");
   case OUT_STATE_SUSPENDED_BOTH:
-    return _("suspended and on hold");
+    return _ ("suspended and on hold");
   }
   return NULL;
 }
@@ -463,33 +461,28 @@ destroy_out (struct OutgoingCall *oc)
 static void
 do_status ()
 {
-  if ( (NULL == active_in) &&
-       (NULL == active_out) &&
-       (0 != in_ring_counter) )
+  if ((NULL == active_in) && (NULL == active_out) && (0 != in_ring_counter))
   {
-    GCG_update_status_bar (_("The phone is ringing (%u calls waiting)"),
+    GCG_update_status_bar (_ ("The phone is ringing (%u calls waiting)"),
                            in_ring_counter);
     return;
   }
-  if ( (NULL == active_in) &&
-       (NULL == active_out) )
+  if ((NULL == active_in) && (NULL == active_out))
   {
     if (NULL != phone)
     {
-      GCG_update_status_bar ("%s",
-                             _("We are listening for incoming calls"));
+      GCG_update_status_bar ("%s", _ ("We are listening for incoming calls"));
     }
     else
     {
       if (NULL == GCG_EGOS_get_selected_ego ())
       {
-        GCG_update_status_bar ("%s",
-                               _("No ego selected, phone is down."));
+        GCG_update_status_bar ("%s", _ ("No ego selected, phone is down."));
       }
       else
       {
         GCG_update_status_bar ("%s",
-                               _("Failed to setup phone (internal error)"));
+                               _ ("Failed to setup phone (internal error)"));
       }
     }
     return;
@@ -505,14 +498,14 @@ do_status ()
       GNUNET_break (0);
       break;
     case IN_STATE_CONNECTED:
-        GCG_update_status_bar (_("In a conversation with `%s'."),
+      GCG_update_status_bar (_ ("In a conversation with `%s'."),
                              active_in->caller_id_str);
       break;
     case IN_STATE_SUSPENDED_LOCAL:
       GNUNET_break (0);
       break;
     case IN_STATE_SUSPENDED_REMOTE:
-      GCG_update_status_bar (_("On hold in a conversation with `%s'."),
+      GCG_update_status_bar (_ ("On hold in a conversation with `%s'."),
                              active_in->caller_id_str);
       break;
     case IN_STATE_SUSPENDED_BOTH:
@@ -529,22 +522,20 @@ do_status ()
       GNUNET_break (0);
       break;
     case OUT_STATE_RESOLVING:
-      GCG_update_status_bar (_("Resolving `%s'."),
-                             active_out->caller_id_str);
+      GCG_update_status_bar (_ ("Resolving `%s'."), active_out->caller_id_str);
       break;
     case OUT_STATE_RINGING:
-      GCG_update_status_bar (_("Calling `%s'."),
-                             active_out->caller_id_str);
+      GCG_update_status_bar (_ ("Calling `%s'."), active_out->caller_id_str);
       break;
     case OUT_STATE_CONNECTED:
-      GCG_update_status_bar (_("In a conversation with `%s'."),
+      GCG_update_status_bar (_ ("In a conversation with `%s'."),
                              active_out->caller_id_str);
       break;
     case OUT_STATE_SUSPENDED_LOCAL:
       GNUNET_break (0);
       break;
     case OUT_STATE_SUSPENDED_REMOTE:
-      GCG_update_status_bar (_("On hold in a conversation with `%s'."),
+      GCG_update_status_bar (_ ("On hold in a conversation with `%s'."),
                              active_out->caller_id_str);
       break;
     case OUT_STATE_SUSPENDED_BOTH:
@@ -595,9 +586,7 @@ update_call_buttons (GtkTreeSelection *sel)
   gint out_state;
   gboolean in_call;
 
-  if (! gtk_tree_selection_get_selected (sel,
-					 &model,
-					 &iter))
+  if (! gtk_tree_selection_get_selected (sel, &model, &iter))
   {
     /* nothing selected, disable buttons */
     gtk_widget_set_sensitive (b_add_contact, FALSE);
@@ -608,12 +597,16 @@ update_call_buttons (GtkTreeSelection *sel)
   }
   in_call = (NULL != active_in) || (NULL != active_out);
   gtk_tree_model_get (model,
-		      &iter,
-		      GCG_PHONE_LS_TYPE, &type,
-		      GCG_PHONE_LS_OUT_CALL_STATE, &out_state,
-		      GCG_PHONE_LS_IN_CALL_STATE, &in_state,
-		      GCG_PHONE_LS_INCOMING_CALL, &ic,
-		      -1);
+                      &iter,
+                      GCG_PHONE_LS_TYPE,
+                      &type,
+                      GCG_PHONE_LS_OUT_CALL_STATE,
+                      &out_state,
+                      GCG_PHONE_LS_IN_CALL_STATE,
+                      &in_state,
+                      GCG_PHONE_LS_INCOMING_CALL,
+                      &ic,
+                      -1);
   switch ((enum TypeOfConversation) type)
   {
   case CALL_IN:
@@ -709,8 +702,9 @@ update_call_buttons (GtkTreeSelection *sel)
  * @param user_data builder context (unused)
  */
 void
-gnunet_conversation_gtk_active_calls_treeview_selection_changed_cb  (GtkTreeSelection *sel,
-								     gpointer user_data)
+gnunet_conversation_gtk_active_calls_treeview_selection_changed_cb (
+  GtkTreeSelection *sel,
+  gpointer user_data)
 {
   update_call_buttons (sel);
 }
@@ -723,18 +717,16 @@ gnunet_conversation_gtk_active_calls_treeview_selection_changed_cb  (GtkTreeSele
 static void
 update_gui ()
 {
-  if ( (NULL != active_in) ||
-       (NULL != active_out) )
+  if ((NULL != active_in) || (NULL != active_out))
   {
     /* in a call, show hangup/suspend buttons */
     gtk_widget_show (b_suspend);
     gtk_widget_show (b_hangup);
     gtk_widget_hide (b_call);
     gtk_widget_set_sensitive (b_hangup, TRUE);
-    if ( (NULL != active_in) ||
-         ( (NULL != active_out) &&
-           (OUT_STATE_RESOLVING != active_out->state) &&
-           (OUT_STATE_RINGING != active_out->state) ) )
+    if ((NULL != active_in) ||
+        ((NULL != active_out) && (OUT_STATE_RESOLVING != active_out->state) &&
+         (OUT_STATE_RINGING != active_out->state)))
       gtk_widget_set_sensitive (b_suspend, TRUE);
     else
       gtk_widget_set_sensitive (b_suspend, FALSE);
@@ -763,23 +755,20 @@ update_gui ()
  * @param state new state of the call
  */
 static void
-set_outgoing_call_state (struct OutgoingCall *oc,
-                         enum OutCallState state)
+set_outgoing_call_state (struct OutgoingCall *oc, enum OutCallState state)
 {
   GtkTreePath *path;
   GtkTreeIter iter;
 
   oc->state = state;
   path = gtk_tree_row_reference_get_path (oc->rr);
-  GNUNET_assert (gtk_tree_model_get_iter (GTK_TREE_MODEL (active_liststore),
-                                          &iter,
-                                          path));
+  GNUNET_assert (
+    gtk_tree_model_get_iter (GTK_TREE_MODEL (active_liststore), &iter, path));
   gtk_tree_path_free (path);
   switch (state)
   {
   case OUT_STATE_NONE:
-    gtk_list_store_remove (active_liststore,
-                           &iter);
+    gtk_list_store_remove (active_liststore, &iter);
     return;
   case OUT_STATE_RESOLVING:
     break;
@@ -796,8 +785,10 @@ set_outgoing_call_state (struct OutgoingCall *oc,
   }
   gtk_list_store_set (active_liststore,
                       &iter,
-                      GCG_PHONE_LS_OUT_CALL_STATE, state,
-                      GCG_PHONE_LS_STATE_NAME, out_call_state_to_string (state),
+                      GCG_PHONE_LS_OUT_CALL_STATE,
+                      state,
+                      GCG_PHONE_LS_STATE_NAME,
+                      out_call_state_to_string (state),
                       -1);
   update_call_buttons (gtk_tree_view_get_selection (active_treeview));
 }
@@ -810,23 +801,20 @@ set_outgoing_call_state (struct OutgoingCall *oc,
  * @param state new state of the call
  */
 static void
-set_incoming_call_state (struct IncomingCall *ic,
-                         enum InCallState state)
+set_incoming_call_state (struct IncomingCall *ic, enum InCallState state)
 {
   GtkTreePath *path;
   GtkTreeIter iter;
 
   ic->state = state;
   path = gtk_tree_row_reference_get_path (ic->rr);
-  GNUNET_assert (gtk_tree_model_get_iter (GTK_TREE_MODEL (active_liststore),
-                                          &iter,
-                                          path));
+  GNUNET_assert (
+    gtk_tree_model_get_iter (GTK_TREE_MODEL (active_liststore), &iter, path));
   gtk_tree_path_free (path);
   switch (state)
   {
   case IN_STATE_NONE:
-    gtk_list_store_remove (active_liststore,
-                           &iter);
+    gtk_list_store_remove (active_liststore, &iter);
     return;
   case IN_STATE_RINGING:
     break;
@@ -841,8 +829,10 @@ set_incoming_call_state (struct IncomingCall *ic,
   }
   gtk_list_store_set (active_liststore,
                       &iter,
-                      GCG_PHONE_LS_IN_CALL_STATE, state,
-                      GCG_PHONE_LS_STATE_NAME, in_call_state_to_string (state),
+                      GCG_PHONE_LS_IN_CALL_STATE,
+                      state,
+                      GCG_PHONE_LS_STATE_NAME,
+                      in_call_state_to_string (state),
                       -1);
   update_call_buttons (gtk_tree_view_get_selection (active_treeview));
 }
@@ -881,7 +871,7 @@ handle_reverse_error (void *cls)
   struct IncomingCall *ic = cls;
 
   ic->qe = NULL;
-  GCG_log (_("Error communicating with namestore!\n"));
+  GCG_log (_ ("Error communicating with namestore!\n"));
 }
 
 
@@ -914,31 +904,39 @@ phone_event_handler (void *cls,
     ic->caller = caller;
     ic->state = IN_STATE_RINGING;
     ic->caller_id = *caller_id;
-    ic->caller_id_str = GNUNET_strdup (GNUNET_GNSRECORD_pkey_to_zkey (caller_id));
+    ic->caller_id_str =
+      GNUNET_strdup (GNUNET_GNSRECORD_pkey_to_zkey (caller_id));
 
     my_zone = GCG_ZONES_get_selected_zone (&tld);
-    ic->qe = GNUNET_NAMESTORE_zone_to_name (GCG_IMPORT_get_namestore (),
-                                            GNUNET_IDENTITY_ego_get_private_key (my_zone),
-                                            &ic->caller_id,
-                                            &handle_reverse_error,
-                                            ic,
-                                            &handle_reverse_lookup_result,
-                                            ic);
+    ic->qe =
+      GNUNET_NAMESTORE_zone_to_name (GCG_IMPORT_get_namestore (),
+                                     GNUNET_IDENTITY_ego_get_private_key (
+                                       my_zone),
+                                     &ic->caller_id,
+                                     &handle_reverse_error,
+                                     ic,
+                                     &handle_reverse_lookup_result,
+                                     ic);
     ic->caller_num = caller_num_gen++;
     gtk_list_store_insert_with_values (active_liststore,
                                        &iter,
                                        -1,
-                                       GCG_PHONE_LS_REMOTE_USER_NAME, ic->caller_id_str,
-                                       GCG_PHONE_LS_INCOMING_CALL, ic,
-                                       GCG_PHONE_LS_NUMBER, ic->caller_num,
-                                       GCG_PHONE_LS_IN_CALL_STATE, ic->state,
-                                       GCG_PHONE_LS_STATE_NAME, in_call_state_to_string (ic->state),
-                                       GCG_PHONE_LS_TYPE, CALL_IN,
+                                       GCG_PHONE_LS_REMOTE_USER_NAME,
+                                       ic->caller_id_str,
+                                       GCG_PHONE_LS_INCOMING_CALL,
+                                       ic,
+                                       GCG_PHONE_LS_NUMBER,
+                                       ic->caller_num,
+                                       GCG_PHONE_LS_IN_CALL_STATE,
+                                       ic->state,
+                                       GCG_PHONE_LS_STATE_NAME,
+                                       in_call_state_to_string (ic->state),
+                                       GCG_PHONE_LS_TYPE,
+                                       CALL_IN,
                                        -1);
-    path = gtk_tree_model_get_path (GTK_TREE_MODEL (active_liststore),
-				    &iter);
-    ic->rr = gtk_tree_row_reference_new (GTK_TREE_MODEL (active_liststore),
-					 path);
+    path = gtk_tree_model_get_path (GTK_TREE_MODEL (active_liststore), &iter);
+    ic->rr =
+      gtk_tree_row_reference_new (GTK_TREE_MODEL (active_liststore), path);
     gtk_tree_path_free (path);
     GCG_HISTORY_add (GCG_HISTORY_TYPE_INCOMING_CALL,
                      ic->caller_id_str,
@@ -947,17 +945,17 @@ phone_event_handler (void *cls,
   case GNUNET_CONVERSATION_EC_PHONE_HUNG_UP:
     GNUNET_break (in_ring_counter > 0);
     in_ring_counter--;
-    valid = gtk_tree_model_get_iter_first (GTK_TREE_MODEL (active_liststore),
-                                           &iter);
+    valid =
+      gtk_tree_model_get_iter_first (GTK_TREE_MODEL (active_liststore), &iter);
     GNUNET_break (valid);
     while (valid)
     {
       gtk_tree_model_get (GTK_TREE_MODEL (active_liststore),
                           &iter,
-                          GCG_PHONE_LS_INCOMING_CALL, &ic,
+                          GCG_PHONE_LS_INCOMING_CALL,
+                          &ic,
                           -1);
-      if ( (NULL != ic) &&
-           (caller == ic->caller) )
+      if ((NULL != ic) && (caller == ic->caller))
       {
         if (ic == active_in)
         {
@@ -977,14 +975,13 @@ phone_event_handler (void *cls,
                              ic->caller_id_str,
                              ic->caller_num);
         }
-        set_incoming_call_state (ic,
-                                 IN_STATE_NONE);
+        set_incoming_call_state (ic, IN_STATE_NONE);
         ic->caller = NULL;
         destroy_in (ic);
         break;
       }
-      valid = gtk_tree_model_iter_next (GTK_TREE_MODEL (active_liststore),
-                                        &iter);
+      valid =
+        gtk_tree_model_iter_next (GTK_TREE_MODEL (active_liststore), &iter);
     }
     GNUNET_break (valid);
     break;
@@ -1000,8 +997,7 @@ phone_event_handler (void *cls,
  * @param code type of the event issued by the caller
  */
 static void
-caller_event_handler (void *cls,
-                      enum GNUNET_CONVERSATION_CallerEventCode code)
+caller_event_handler (void *cls, enum GNUNET_CONVERSATION_CallerEventCode code)
 {
   struct IncomingCall *ic = cls;
   enum InCallState is;
@@ -1039,8 +1035,7 @@ caller_event_handler (void *cls,
       GNUNET_assert (0);
       break;
     }
-    set_incoming_call_state (ic,
-                             is);
+    set_incoming_call_state (ic, is);
     break;
   case GNUNET_CONVERSATION_EC_CALLER_RESUME:
     GCG_HISTORY_add (GCG_HISTORY_TYPE_RESUMED_REMOTE,
@@ -1068,11 +1063,10 @@ caller_event_handler (void *cls,
       is = IN_STATE_SUSPENDED_LOCAL;
       break;
     }
-    set_incoming_call_state (ic,
-			     is);
+    set_incoming_call_state (ic, is);
     break;
   }
-  do_status();
+  do_status ();
 }
 
 
@@ -1091,26 +1085,20 @@ gnunet_conversation_gtk_accept_button_clicked_cb (GtkButton *button,
   GtkTreeIter iter;
   GtkTreeModel *model;
 
-  if ( (NULL != active_in) ||
-       (NULL != active_out) )
+  if ((NULL != active_in) || (NULL != active_out))
   {
     /* accept button should not have been sensitive! */
     GNUNET_break (0);
     return;
   }
   sel = gtk_tree_view_get_selection (active_treeview);
-  if (! gtk_tree_selection_get_selected (sel,
-					 &model,
-					 &iter))
+  if (! gtk_tree_selection_get_selected (sel, &model, &iter))
   {
     /* accept button should not have been sensitive! */
     GNUNET_break (0);
     return;
   }
-  gtk_tree_model_get (model,
-		      &iter,
-		      GCG_PHONE_LS_INCOMING_CALL, &ic,
-		      -1);
+  gtk_tree_model_get (model, &iter, GCG_PHONE_LS_INCOMING_CALL, &ic, -1);
   if (NULL == ic)
   {
     /* accept button should not have been sensitive! */
@@ -1118,16 +1106,16 @@ gnunet_conversation_gtk_accept_button_clicked_cb (GtkButton *button,
     return;
   }
   active_in = ic;
-  set_incoming_call_state (ic,
-                           IN_STATE_CONNECTED);
+  set_incoming_call_state (ic, IN_STATE_CONNECTED);
   GNUNET_CONVERSATION_caller_pick_up (ic->caller,
-                                      &caller_event_handler, ic,
-                                      speaker, mic);
+                                      &caller_event_handler,
+                                      ic,
+                                      speaker,
+                                      mic);
   GCG_HISTORY_add (GCG_HISTORY_TYPE_INCOMING_ACCEPTED,
                    ic->caller_id_str,
                    ic->caller_num);
-  gtk_entry_set_text (address_entry,
-                      ic->caller_id_str);
+  gtk_entry_set_text (address_entry, ic->caller_id_str);
   update_gui ();
 }
 
@@ -1149,19 +1137,19 @@ gnunet_conversation_gtk_refuse_button_clicked_cb (GtkButton *button,
   GtkTreeModel *model;
 
   sel = gtk_tree_view_get_selection (active_treeview);
-  if (! gtk_tree_selection_get_selected (sel,
-					 &model,
-					 &iter))
+  if (! gtk_tree_selection_get_selected (sel, &model, &iter))
   {
     /* reject button should not have been sensitive! */
     GNUNET_break (0);
     return;
   }
   gtk_tree_model_get (model,
-		      &iter,
-		      GCG_PHONE_LS_INCOMING_CALL, &ic,
-		      GCG_PHONE_LS_OUTGOING_CALL, &oc,
-		      -1);
+                      &iter,
+                      GCG_PHONE_LS_INCOMING_CALL,
+                      &ic,
+                      GCG_PHONE_LS_OUTGOING_CALL,
+                      &oc,
+                      -1);
   if (NULL != ic)
   {
     if (active_in == ic)
@@ -1173,10 +1161,9 @@ gnunet_conversation_gtk_refuse_button_clicked_cb (GtkButton *button,
     GNUNET_break (in_ring_counter > 0);
     in_ring_counter--;
     GCG_HISTORY_add (GCG_HISTORY_TYPE_INCOMING_REJECTED,
-		     ic->caller_id_str,
+                     ic->caller_id_str,
                      ic->caller_num);
-    set_incoming_call_state (ic,
-			     IN_STATE_NONE);
+    set_incoming_call_state (ic, IN_STATE_NONE);
     destroy_in (ic);
     do_status ();
     return;
@@ -1191,10 +1178,9 @@ gnunet_conversation_gtk_refuse_button_clicked_cb (GtkButton *button,
       return;
     }
     GCG_HISTORY_add (GCG_HISTORY_TYPE_HANGUP,
-		     oc->caller_id_str,
+                     oc->caller_id_str,
                      oc->caller_num);
-    set_outgoing_call_state (oc,
-			     OUT_STATE_NONE);
+    set_outgoing_call_state (oc, OUT_STATE_NONE);
     destroy_out (oc);
     do_status ();
     return;
@@ -1220,55 +1206,48 @@ gnunet_conversation_gtk_resume_button_clicked_cb (GtkButton *button,
   GtkTreeIter iter;
   GtkTreeModel *model;
 
-  if ( (NULL != active_in) ||
-       (NULL != active_out) )
+  if ((NULL != active_in) || (NULL != active_out))
   {
     /* resume button should have been inactive */
-    GNUNET_break(0);
+    GNUNET_break (0);
     return;
   }
 
   sel = gtk_tree_view_get_selection (active_treeview);
-  if (! gtk_tree_selection_get_selected (sel,
-					 &model,
-					 &iter))
+  if (! gtk_tree_selection_get_selected (sel, &model, &iter))
   {
     /* resume button should not have been sensitive! */
     GNUNET_break (0);
     return;
   }
   gtk_tree_model_get (model,
-		      &iter,
-		      GCG_PHONE_LS_INCOMING_CALL, &ic,
-		      GCG_PHONE_LS_OUTGOING_CALL, &oc,
-		      -1);
+                      &iter,
+                      GCG_PHONE_LS_INCOMING_CALL,
+                      &ic,
+                      GCG_PHONE_LS_OUTGOING_CALL,
+                      &oc,
+                      -1);
   if (NULL != ic)
   {
     active_in = ic;
-    set_incoming_call_state (ic,
-			     IN_STATE_CONNECTED);
-    GNUNET_CONVERSATION_caller_resume (ic->caller,
-				       speaker, mic);
+    set_incoming_call_state (ic, IN_STATE_CONNECTED);
+    GNUNET_CONVERSATION_caller_resume (ic->caller, speaker, mic);
     GCG_HISTORY_add (GCG_HISTORY_TYPE_RESUMED_LOCAL,
                      ic->caller_id_str,
                      ic->caller_num);
-    gtk_entry_set_text (address_entry,
-                        ic->caller_id_str);
+    gtk_entry_set_text (address_entry, ic->caller_id_str);
     update_gui ();
     return;
   }
   if (NULL != oc)
   {
     active_out = oc;
-    GNUNET_CONVERSATION_call_resume (oc->call,
-                                     speaker, mic);
-    set_outgoing_call_state (oc,
-                             OUT_STATE_CONNECTED);
+    GNUNET_CONVERSATION_call_resume (oc->call, speaker, mic);
+    set_outgoing_call_state (oc, OUT_STATE_CONNECTED);
     GCG_HISTORY_add (GCG_HISTORY_TYPE_RESUMED_LOCAL,
                      oc->caller_id_str,
                      oc->caller_num);
-    gtk_entry_set_text (address_entry,
-                        active_out->caller_id_str);
+    gtk_entry_set_text (address_entry, active_out->caller_id_str);
     update_gui ();
     return;
   }
@@ -1290,10 +1269,9 @@ gnunet_conversation_gtk_suspend_button_clicked_cb (GtkButton *button,
   enum OutCallState os;
   enum InCallState is;
 
-  if ( (NULL != active_in) &&
-       (NULL != active_out) )
+  if ((NULL != active_in) && (NULL != active_out))
   {
-    GNUNET_break(0);
+    GNUNET_break (0);
     return;
   }
   if (NULL != active_out)
@@ -1327,8 +1305,7 @@ gnunet_conversation_gtk_suspend_button_clicked_cb (GtkButton *button,
       break;
     }
     GNUNET_CONVERSATION_call_suspend (active_out->call);
-    set_outgoing_call_state (active_out,
-                             os);
+    set_outgoing_call_state (active_out, os);
     active_out = NULL;
     update_gui ();
     return;
@@ -1361,8 +1338,7 @@ gnunet_conversation_gtk_suspend_button_clicked_cb (GtkButton *button,
       GNUNET_assert (0);
       break;
     }
-    set_incoming_call_state (active_in,
-                             is);
+    set_incoming_call_state (active_in, is);
     active_in = NULL;
     update_gui ();
     return;
@@ -1381,10 +1357,9 @@ void
 gnunet_conversation_gtk_hangup_button_clicked_cb (GtkButton *button,
                                                   gpointer user_data)
 {
-  if ( (NULL == active_in) &&
-       (NULL == active_out) )
+  if ((NULL == active_in) && (NULL == active_out))
   {
-    GNUNET_break(0);
+    GNUNET_break (0);
     return;
   }
   if (NULL != active_out)
@@ -1393,8 +1368,7 @@ gnunet_conversation_gtk_hangup_button_clicked_cb (GtkButton *button,
     GCG_HISTORY_add (GCG_HISTORY_TYPE_HANGUP,
                      active_out->caller_id_str,
                      active_out->caller_num);
-    set_outgoing_call_state (active_out,
-                             OUT_STATE_NONE);
+    set_outgoing_call_state (active_out, OUT_STATE_NONE);
     destroy_out (active_out);
     active_out = NULL;
     update_gui ();
@@ -1406,8 +1380,7 @@ gnunet_conversation_gtk_hangup_button_clicked_cb (GtkButton *button,
     GCG_HISTORY_add (GCG_HISTORY_TYPE_HANGUP,
                      active_in->caller_id_str,
                      active_in->caller_num);
-    set_incoming_call_state (active_in,
-                             IN_STATE_NONE);
+    set_incoming_call_state (active_in, IN_STATE_NONE);
     destroy_in (active_in);
     active_in = NULL;
     update_gui ();
@@ -1424,8 +1397,7 @@ gnunet_conversation_gtk_hangup_button_clicked_cb (GtkButton *button,
  * @param code type of the event on the call
  */
 static void
-call_event_handler (void *cls,
-                    enum GNUNET_CONVERSATION_CallEventCode code)
+call_event_handler (void *cls, enum GNUNET_CONVERSATION_CallEventCode code)
 {
   struct OutgoingCall *oc = cls;
   enum OutCallState os;
@@ -1438,8 +1410,7 @@ call_event_handler (void *cls,
                      oc->caller_num);
     GNUNET_break (OUT_STATE_RESOLVING == oc->state);
     GNUNET_break (active_out == oc);
-    set_outgoing_call_state (oc,
-			     OUT_STATE_RINGING);
+    set_outgoing_call_state (oc, OUT_STATE_RINGING);
     do_status ();
     break;
   case GNUNET_CONVERSATION_EC_CALL_PICKED_UP:
@@ -1458,8 +1429,7 @@ call_event_handler (void *cls,
                      oc->caller_num);
     GNUNET_break (OUT_STATE_RESOLVING == oc->state);
     GNUNET_break (active_out == oc);
-    set_outgoing_call_state (oc,
-			     OUT_STATE_NONE);
+    set_outgoing_call_state (oc, OUT_STATE_NONE);
     oc->call = NULL;
     destroy_out (oc);
     active_out = NULL;
@@ -1576,9 +1546,7 @@ gnunet_conversation_gtk_call_button_clicked_cb (GtkButton *button,
 
   arg = gtk_entry_get_text (address_entry);
   caller_id = GCG_EGOS_get_selected_ego ();
-  if ( (NULL == caller_id) ||
-       (NULL != active_out) ||
-       (NULL != active_in) )
+  if ((NULL == caller_id) || (NULL != active_out) || (NULL != active_in))
   {
     GNUNET_break (0);
     return;
@@ -1590,14 +1558,13 @@ gnunet_conversation_gtk_call_button_clicked_cb (GtkButton *button,
   GCG_HISTORY_add (GCG_HISTORY_TYPE_OUTGOING_CALL,
                    oc->caller_id_str,
                    oc->caller_num);
-  oc->call =
-    GNUNET_CONVERSATION_call_start (GCG_get_configuration (),
-                                    caller_id,
-                                    arg,
-                                    speaker,
-                                    mic,
-                                    &call_event_handler,
-                                    oc);
+  oc->call = GNUNET_CONVERSATION_call_start (GCG_get_configuration (),
+                                             caller_id,
+                                             arg,
+                                             speaker,
+                                             mic,
+                                             &call_event_handler,
+                                             oc);
   if (NULL == oc->call)
   {
     GCG_HISTORY_add (GCG_HISTORY_TYPE_FAILED,
@@ -1610,20 +1577,26 @@ gnunet_conversation_gtk_call_button_clicked_cb (GtkButton *button,
   gtk_list_store_insert_with_values (active_liststore,
                                      &iter,
                                      -1,
-                                     GCG_PHONE_LS_REMOTE_USER_NAME, oc->caller_id_str,
-                                     GCG_PHONE_LS_INCOMING_CALL, NULL,
-                                     GCG_PHONE_LS_NUMBER, oc->caller_num,
-                                     GCG_PHONE_LS_IN_CALL_STATE, IN_STATE_NONE,
-                                     GCG_PHONE_LS_TYPE, CALL_OUT,
-                                     GCG_PHONE_LS_OUTGOING_CALL, oc,
-                                     GCG_PHONE_LS_OUT_CALL_STATE, oc->state,
-				     GCG_PHONE_LS_STATE_NAME, out_call_state_to_string (oc->state),
+                                     GCG_PHONE_LS_REMOTE_USER_NAME,
+                                     oc->caller_id_str,
+                                     GCG_PHONE_LS_INCOMING_CALL,
+                                     NULL,
+                                     GCG_PHONE_LS_NUMBER,
+                                     oc->caller_num,
+                                     GCG_PHONE_LS_IN_CALL_STATE,
+                                     IN_STATE_NONE,
+                                     GCG_PHONE_LS_TYPE,
+                                     CALL_OUT,
+                                     GCG_PHONE_LS_OUTGOING_CALL,
+                                     oc,
+                                     GCG_PHONE_LS_OUT_CALL_STATE,
+                                     oc->state,
+                                     GCG_PHONE_LS_STATE_NAME,
+                                     out_call_state_to_string (oc->state),
 
                                      -1);
-  path = gtk_tree_model_get_path (GTK_TREE_MODEL (active_liststore),
-				  &iter);
-  oc->rr = gtk_tree_row_reference_new (GTK_TREE_MODEL (active_liststore),
-				       path);
+  path = gtk_tree_model_get_path (GTK_TREE_MODEL (active_liststore), &iter);
+  oc->rr = gtk_tree_row_reference_new (GTK_TREE_MODEL (active_liststore), path);
   gtk_tree_path_free (path);
   update_gui ();
 }
@@ -1654,12 +1627,9 @@ update_copy_sensitivity ()
   struct GNUNET_IDENTITY_Ego *ego;
 
   ego = GCG_EGOS_get_selected_ego ();
-  label = gtk_entry_get_text (GTK_ENTRY
-                              (GCG_get_main_window_object
-                               ("gnunet_conversation_gtk_ego_label_entry")));
-  if ( (NULL == ego) ||
-       (NULL == label) ||
-       (0 == strlen (label)) )
+  label = gtk_entry_get_text (GTK_ENTRY (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_ego_label_entry")));
+  if ((NULL == ego) || (NULL == label) || (0 == strlen (label)))
     gtk_widget_set_sensitive (b_copy, FALSE);
   else
     gtk_widget_set_sensitive (b_copy, TRUE);
@@ -1681,17 +1651,14 @@ update_phone_record ()
     GSC_remove_phone ();
     return;
   }
-  label = gtk_entry_get_text (GTK_ENTRY
-                              (GCG_get_main_window_object
-                               ("gnunet_conversation_gtk_ego_label_entry")));
-  if ( (NULL == label) ||
-       (0 == strlen (label)) )
+  label = gtk_entry_get_text (GTK_ENTRY (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_ego_label_entry")));
+  if ((NULL == label) || (0 == strlen (label)))
   {
     GSC_remove_phone ();
     return;
   }
-  GNUNET_CONVERSATION_phone_get_record (phone,
-                                        &rd);
+  GNUNET_CONVERSATION_phone_get_record (phone, &rd);
   GSC_add_phone (label, &rd);
 }
 
@@ -1712,20 +1679,15 @@ gnunet_conversation_gtk_ego_label_entry_preedit_changed_cb (GtkEntry *entry,
 {
   GtkComboBoxText *cbt;
 
-  if (GNUNET_OK !=
-      GNUNET_DNSPARSER_check_label (preedit))
+  if (GNUNET_OK != GNUNET_DNSPARSER_check_label (preedit))
   {
-    GCG_log (_("Invalid label `%s'\n"),
-             preedit);
-    gdk_display_beep (gdk_display_get_default());
+    GCG_log (_ ("Invalid label `%s'\n"), preedit);
+    gdk_display_beep (gdk_display_get_default ());
     return;
   }
-  cbt = GTK_COMBO_BOX_TEXT (GCG_get_main_window_object
-                            ("gnunet_conversation_gtk_ego_label_comboboxtext"));
-  gtk_combo_box_text_insert (cbt,
-                             -1,
-                             NULL,
-                             preedit);
+  cbt = GTK_COMBO_BOX_TEXT (GCG_get_main_window_object (
+    "gnunet_conversation_gtk_ego_label_comboboxtext"));
+  gtk_combo_box_text_insert (cbt, -1, NULL, preedit);
   update_copy_sensitivity ();
   update_phone_record ();
 }
@@ -1775,24 +1737,21 @@ gnunet_conversation_gtk_ego_combobox_changed_cb (GtkComboBox *widget,
     return;
   }
   cfg = GCG_get_configuration ();
-  if (GNUNET_OK !=
-      GNUNET_CONFIGURATION_get_value_number (cfg,
-                                             "CONVERSATION",
-                                             "LINE",
-                                             &line))
+  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_number (cfg,
+                                                          "CONVERSATION",
+                                                          "LINE",
+                                                          &line))
   {
-    GCG_log (_("No phone line specified in configuration!\n"));
+    GCG_log (_ ("No phone line specified in configuration!\n"));
     do_status ();
     check_call_sensitivity ();
     return;
   }
-  GCG_log (_("Initializing phone on line %llu\n"),
-           line);
-  phone =
-    GNUNET_CONVERSATION_phone_create (cfg,
-                                      caller_id,
-                                      &phone_event_handler,
-                                      NULL);
+  GCG_log (_ ("Initializing phone on line %llu\n"), line);
+  phone = GNUNET_CONVERSATION_phone_create (cfg,
+                                            caller_id,
+                                            &phone_event_handler,
+                                            NULL);
   if (NULL == phone)
   {
     check_call_sensitivity ();
@@ -1817,30 +1776,28 @@ GCG_PHONE_init ()
   cfg = GCG_get_configuration ();
   speaker = GNUNET_SPEAKER_create_from_hardware (cfg);
   mic = GNUNET_MICROPHONE_create_from_hardware (cfg);
-  b_add_contact = GTK_WIDGET (GCG_get_main_window_object
-                              ("gnunet_conversation_gtk_add_contact_button"));
-  b_accept  = GTK_WIDGET (GCG_get_main_window_object
-                          ("gnunet_conversation_gtk_accept_button"));
-  b_refuse  = GTK_WIDGET (GCG_get_main_window_object
-                          ("gnunet_conversation_gtk_refuse_button"));
-  b_suspend = GTK_WIDGET (GCG_get_main_window_object
-                          ("gnunet_conversation_gtk_suspend_button"));
-  b_resume  = GTK_WIDGET (GCG_get_main_window_object
-                          ("gnunet_conversation_gtk_resume_button"));
-  b_call = GTK_WIDGET (GCG_get_main_window_object
-                          ("gnunet_conversation_gtk_call_button"));
-  b_hangup = GTK_WIDGET (GCG_get_main_window_object
-                         ("gnunet_conversation_gtk_hangup_button"));
-  b_copy = GTK_WIDGET (GCG_get_main_window_object
-                       ("gnunet_conversation_gtk_ego_copy_button"));
-  address_entry = GTK_ENTRY (GCG_get_main_window_object
-                             ("gnunet_conversation_gtk_address_entry"));
-  active_liststore =
-     GTK_LIST_STORE (GCG_get_main_window_object
-                     ("gnunet_conversation_gtk_active_calls_liststore"));
-  active_treeview =
-      GTK_TREE_VIEW (GCG_get_main_window_object
-                     ("gnunet_conversation_gtk_active_calls_treeview"));
+  b_add_contact = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_add_contact_button"));
+  b_accept = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_accept_button"));
+  b_refuse = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_refuse_button"));
+  b_suspend = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_suspend_button"));
+  b_resume = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_resume_button"));
+  b_call = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_call_button"));
+  b_hangup = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_hangup_button"));
+  b_copy = GTK_WIDGET (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_ego_copy_button"));
+  address_entry = GTK_ENTRY (
+    GCG_get_main_window_object ("gnunet_conversation_gtk_address_entry"));
+  active_liststore = GTK_LIST_STORE (GCG_get_main_window_object (
+    "gnunet_conversation_gtk_active_calls_liststore"));
+  active_treeview = GTK_TREE_VIEW (GCG_get_main_window_object (
+    "gnunet_conversation_gtk_active_calls_treeview"));
   do_status ();
 }
 
