@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010-2013 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010-2013 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -44,7 +44,6 @@
  */
 #define DEFAULT_MAX_PARALLEL_DOWNLOADS 128
 
-#define SERVICE_LIST_TIMEOUT GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_SECONDS, 1)
 
 /**
  * The GNUNET_GTK_file_sharing_downloads_tree_store with the
@@ -52,11 +51,6 @@
  */
 GtkTreeStore *downloads_treestore;
 
-/**
- * Should gnunet-fs-gtk start in tray mode?
- */
-static int tray_only;
-
 /**
  * Handle to our main loop.
  */
@@ -153,7 +147,8 @@ GNUNET_FS_GTK_get_main_window_object (const char *name)
 GtkTreeModel *
 GNUNET_FS_GTK_get_anonymity_level_list_store ()
 {
-  return GTK_TREE_MODEL (GNUNET_FS_GTK_get_main_window_object ("anonymity_level_liststore"));
+  return GTK_TREE_MODEL (
+    GNUNET_FS_GTK_get_main_window_object ("anonymity_level_liststore"));
 }
 
 
@@ -176,35 +171,48 @@ main_window_save_position (GtkWidget *main_window)
   struct GNUNET_CONFIGURATION_Handle *cfg;
   struct GNUNET_CONFIGURATION_Handle *cfgDefault;
 
-  cfg = (struct GNUNET_CONFIGURATION_Handle *) GNUNET_GTK_main_loop_get_configuration (ml);
+  cfg = (struct GNUNET_CONFIGURATION_Handle *)
+    GNUNET_GTK_main_loop_get_configuration (ml);
   main_window_gdk = gtk_widget_get_window (main_window);
   maximized = GNUNET_YES;
   if (NULL != main_window_gdk)
   {
     window_state = gdk_window_get_state (main_window_gdk);
-    if (!(window_state & GDK_WINDOW_STATE_MAXIMIZED))
+    if (! (window_state & GDK_WINDOW_STATE_MAXIMIZED))
       maximized = GNUNET_NO;
   }
 
   gtk_window_get_position (GTK_WINDOW (main_window), &window_x, &window_y);
   gtk_window_get_size (GTK_WINDOW (main_window), &window_width, &window_height);
 
-  GNUNET_CONFIGURATION_set_value_number (cfg, "gnunet-fs-gtk",
-					 "MAIN_WINDOW_X", window_x);
-  GNUNET_CONFIGURATION_set_value_number (cfg, "gnunet-fs-gtk",
-					 "MAIN_WINDOW_Y", window_y);
-  GNUNET_CONFIGURATION_set_value_number (cfg, "gnunet-fs-gtk",
-					 "MAIN_WINDOW_WIDTH", window_width);
-  GNUNET_CONFIGURATION_set_value_number (cfg, "gnunet-fs-gtk",
-					 "MAIN_WINDOW_HEIGHT", window_height);
-  GNUNET_CONFIGURATION_set_value_string (cfg, "gnunet-fs-gtk",
-					 "MAIN_WINDOW_MAXIMIZED",
-					 (maximized == GNUNET_YES) ? "YES" : "NO");
+  GNUNET_CONFIGURATION_set_value_number (cfg,
+                                         "gnunet-fs-gtk",
+                                         "MAIN_WINDOW_X",
+                                         window_x);
+  GNUNET_CONFIGURATION_set_value_number (cfg,
+                                         "gnunet-fs-gtk",
+                                         "MAIN_WINDOW_Y",
+                                         window_y);
+  GNUNET_CONFIGURATION_set_value_number (cfg,
+                                         "gnunet-fs-gtk",
+                                         "MAIN_WINDOW_WIDTH",
+                                         window_width);
+  GNUNET_CONFIGURATION_set_value_number (cfg,
+                                         "gnunet-fs-gtk",
+                                         "MAIN_WINDOW_HEIGHT",
+                                         window_height);
+  GNUNET_CONFIGURATION_set_value_string (cfg,
+                                         "gnunet-fs-gtk",
+                                         "MAIN_WINDOW_MAXIMIZED",
+                                         (maximized == GNUNET_YES) ? "YES"
+                                                                   : "NO");
 
   cfgDefault = GNUNET_CONFIGURATION_create ();
   (void) GNUNET_CONFIGURATION_load (cfgDefault, NULL); /* load defaults only */
-  GNUNET_CONFIGURATION_write_diffs (cfgDefault, cfg,
-				    GNUNET_GTK_main_loop_get_configuration_file (ml));
+  GNUNET_CONFIGURATION_write_diffs (cfgDefault,
+                                    cfg,
+                                    GNUNET_GTK_main_loop_get_configuration_file (
+                                      ml));
   GNUNET_CONFIGURATION_destroy (cfgDefault);
 }
 
@@ -219,8 +227,8 @@ main_window_save_position (GtkWidget *main_window)
  */
 gboolean
 GNUNET_GTK_main_window_configure_event_cb (GtkWidget *main_window,
-				           GdkEventConfigure *event,
-				           gpointer user_data)
+                                           GdkEventConfigure *event,
+                                           gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_context = user_data;
 
@@ -233,24 +241,19 @@ GNUNET_GTK_main_window_configure_event_cb (GtkWidget *main_window,
  * Task run on shutdown.
  *
  * @param cls NULL
- * @param tc scheduler context, unused
  */
 static void
-shutdown_task (void *cls,
-               const struct GNUNET_SCHEDULER_TaskContext *tc)
+shutdown_task (void *cls)
 {
   struct SearchLookup *sl;
   struct PseuLookupContext *lctx;
   struct SearchResult *sr;
 
-  GNUNET_GTK_tray_icon_destroy ();
   while (NULL != (sr = pl_head))
   {
     GNUNET_FS_probe_stop (sr->probe);
     sr->probe = NULL;
-    GNUNET_CONTAINER_DLL_remove (pl_head,
-                                 pl_tail,
-                                 sr);
+    GNUNET_CONTAINER_DLL_remove (pl_head, pl_tail, sr);
   }
   if (NULL != fs)
   {
@@ -259,12 +262,12 @@ shutdown_task (void *cls,
   }
   if (NULL != armon)
   {
-    GNUNET_ARM_monitor_disconnect_and_free (armon);
+    GNUNET_ARM_monitor_stop (armon);
     armon = NULL;
   }
   if (NULL != arm)
   {
-    GNUNET_ARM_disconnect_and_free (arm);
+    GNUNET_ARM_disconnect (arm);
     arm = NULL;
   }
   GNUNET_FS_GTK_close_uri_tab_ ();
@@ -312,8 +315,7 @@ shutdown_task (void *cls,
  * @param user_data global builder instance, unused
  */
 void
-GNUNET_FS_GTK_menu_quit_activate_cb (GtkMenuItem *object,
-				     gpointer user_data)
+GNUNET_FS_GTK_menu_quit_activate_cb (GtkMenuItem *object, gpointer user_data)
 {
   GNUNET_SCHEDULER_shutdown ();
 }
@@ -328,8 +330,8 @@ GNUNET_FS_GTK_menu_quit_activate_cb (GtkMenuItem *object,
  */
 void
 GNUNET_FS_GTK_delete_event_cb (GtkWidget *object,
-			       GdkEvent *event,
-			       gpointer user_data)
+                               GdkEvent *event,
+                               gpointer user_data)
 {
   /* GNUNET_FS_GTK_delete_event_cb will eventually be called if we shut down
    * the scheduler, because shutting it down will make GTK delete the main
@@ -339,10 +341,6 @@ GNUNET_FS_GTK_delete_event_cb (GtkWidget *object,
    * just to be sure it is dead (if it isn't, application will hang up).
    */
   GNUNET_SCHEDULER_shutdown ();
-
-  GNUNET_GTK_tray_icon_destroy ();
-  GNUNET_SCHEDULER_add_with_priority (GNUNET_SCHEDULER_PRIORITY_IDLE,
-                                      &shutdown_task, NULL);
 }
 
 
@@ -355,9 +353,7 @@ GNUNET_FS_GTK_delete_event_cb (GtkWidget *object,
  * @param data NULL
  */
 static void
-process_paste (GtkClipboard *cb,
-	       const gchar *text,
-	       gpointer data)
+process_paste (GtkClipboard *cb, const gchar *text, gpointer data)
 {
   struct GNUNET_FS_Uri *kskuri;
   char *emsg;
@@ -388,15 +384,14 @@ process_paste (GtkClipboard *cb,
  *         TRUE if there is now a pop-up menu
  */
 gboolean
-GNUNET_FS_GTK_main_window_button_press_event (GtkWidget * widget,
-					      GdkEvent * event,
-					      gpointer user_data)
+GNUNET_FS_GTK_main_window_button_press_event (GtkWidget *widget,
+                                              GdkEvent *event,
+                                              gpointer user_data)
 {
   GdkEventButton *event_button = (GdkEventButton *) event;
   GtkClipboard *cb;
 
-  if ( (GDK_BUTTON_PRESS != event->type) ||
-       (2 != event_button->button) )
+  if ((GDK_BUTTON_PRESS != event->type) || (2 != event_button->button))
     return FALSE;
   cb = gtk_clipboard_get (gdk_atom_intern ("PRIMARY", FALSE));
   gtk_clipboard_request_text (cb, &process_paste, NULL);
@@ -418,57 +413,57 @@ GNUNET_FS_GTK_main_window_button_press_event (GtkWidget * widget,
  */
 static UniqueResponse
 unique_app_message_cb (UniqueApp *app,
-		       gint command,
-		       UniqueMessageData *message_data,
-		       guint time_,
-		       gpointer user_data)
+                       gint command,
+                       UniqueMessageData *message_data,
+                       guint time_,
+                       gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_context = user_data;
 
   /* raise the window */
-  gtk_window_present_with_time (GTK_WINDOW (main_context->main_window), time_);
+  if (GTK_IS_WINDOW (main_context->main_window))
+    gtk_window_present_with_time (GTK_WINDOW (main_context->main_window),
+                                  time_);
 
   switch (command)
-    {
-    case UNIQUE_NEW:
-      /* this is unexpected... */
-      GNUNET_break (0);
-      break;
-    case UNIQUE_OPEN:
-      {
-        gchar **uris;
-        gint n_uris;
-	gint i;
+  {
+  case UNIQUE_NEW:
+    /* this is unexpected... */
+    GNUNET_break (0);
+    break;
+  case UNIQUE_OPEN: {
+    gchar **uris;
+    gint n_uris;
+    gint i;
 
-        uris = unique_message_data_get_uris (message_data);
-        n_uris = g_strv_length (uris);
-        for (i = 0; i < n_uris; i++)
-	{
-	  if (GNUNET_OK !=
-	      GNUNET_FS_GTK_handle_uri_string (uris[i],
-					       1 /* anonymity level */))
-	    return UNIQUE_RESPONSE_PASSTHROUGH;
-	}
-        g_strfreev (uris);
-      }
-      break;
-    case UNIQUE_ACTIVATE:
-      break;
-    default:
-      break;
+    uris = unique_message_data_get_uris (message_data);
+    n_uris = g_strv_length (uris);
+    for (i = 0; i < n_uris; i++)
+    {
+      if (GNUNET_OK !=
+          GNUNET_FS_GTK_handle_uri_string (uris[i], 1 /* anonymity level */))
+        return UNIQUE_RESPONSE_PASSTHROUGH;
     }
+    g_strfreev (uris);
+  }
+  break;
+  case UNIQUE_ACTIVATE:
+    break;
+  default:
+    break;
+  }
   return UNIQUE_RESPONSE_OK;
 }
 #endif
 
 
 static char *
-format_service_list (unsigned int count, const char *const*list)
+format_service_list (unsigned int count, const char *const *list)
 {
   size_t len = 0;
   int i;
-  const char *header = _("GNUnet node appears to be on.");
-  const char *listheader = _("Currently running services:\n");
+  const char *header = _ ("GNUnet node appears to be on.");
+  const char *listheader = _ ("Currently running services:\n");
   char *result;
   char *p;
   int r;
@@ -517,9 +512,9 @@ format_service_list (unsigned int count, const char *const*list)
 
 static void
 service_list_callback (void *cls,
-		       enum GNUNET_ARM_RequestStatus rs,
-		       unsigned int count,
-		       const char *const*list)
+                       enum GNUNET_ARM_RequestStatus rs,
+                       unsigned int count,
+                       const char *const *list)
 {
   char *service_list;
 
@@ -532,8 +527,7 @@ service_list_callback (void *cls,
 
 
 static void
-arm_connection_state_change (void *cls,
-			     int connected)
+arm_connection_state_change (void *cls, int connected)
 {
   char *service_list;
 
@@ -542,28 +536,48 @@ arm_connection_state_change (void *cls,
     service_list = format_service_list (0, NULL);
     GNUNET_FS_GTK_update_connection_indicator (cls, TRUE, service_list);
     GNUNET_free_non_null (service_list);
-    GNUNET_ARM_request_service_list (arm, SERVICE_LIST_TIMEOUT,
-				     &service_list_callback, cls);
+    GNUNET_ARM_request_service_list (arm, &service_list_callback, cls);
   }
   else
-    GNUNET_FS_GTK_update_connection_indicator (cls, FALSE,
-        _("Can't connect to the Automatic Restart Manager service."));
+    GNUNET_FS_GTK_update_connection_indicator (
+      cls,
+      FALSE,
+      _ ("Can't connect to the Automatic Restart Manager service."));
 }
 
 
 static void
 service_status_change (void *cls,
-		       const char *service,
-		       enum GNUNET_ARM_ServiceStatus status)
+                       const char *service,
+                       enum GNUNET_ARM_ServiceStatus status)
 {
   /* Very crude, we can probably do better.
    * Maybe keep a list of running services, and modify it in response
    * to service status changes, then update the indicator,
    * without requesting a list from ARM every goddamned time?
    */
-  GNUNET_ARM_request_service_list (arm,
-				   SERVICE_LIST_TIMEOUT,
-				   &service_list_callback, cls);
+  GNUNET_ARM_request_service_list (arm, &service_list_callback, cls);
+}
+
+
+static void
+monitor_zone_error (void *cls)
+{
+  GtkListStore *ls;
+
+  ls = GTK_LIST_STORE (
+    GNUNET_FS_GTK_get_main_window_object ("namespace_label_liststore"));
+  gtk_list_store_clear (ls);
+  gtk_widget_hide (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_combobox")));
+}
+
+
+static void
+monitor_zone_sync (void *cls)
+{
+  gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_combobox")));
 }
 
 
@@ -581,10 +595,10 @@ service_status_change (void *cls,
  */
 static void
 monitor_zone_records (void *cls,
-		      const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
-		      const char *label,
-		      unsigned int rd_count,
-		      const struct GNUNET_GNSRECORD_Data *rd)
+                      const struct GNUNET_CRYPTO_EcdsaPrivateKey *zone,
+                      const char *label,
+                      unsigned int rd_count,
+                      const struct GNUNET_GNSRECORD_Data *rd)
 {
   GtkListStore *ls;
   GtkTreeModel *tm;
@@ -592,42 +606,30 @@ monitor_zone_records (void *cls,
   gchar *id;
   gchar *label_gnu;
 
-  ls = GTK_LIST_STORE (GNUNET_FS_GTK_get_main_window_object ("namespace_label_liststore"));
-  if (NULL == zone)
-  {
-    gtk_list_store_clear (ls);
-    return;
-  }
-  label_gnu = g_strdup_printf ("%s.%s",
-			       label,
-			       "gnu");
+  GNUNET_NAMESTORE_zone_monitor_next (main_context.zm, 1);
+  ls = GTK_LIST_STORE (
+    GNUNET_FS_GTK_get_main_window_object ("namespace_label_liststore"));
+  label_gnu = g_strdup_printf ("%s.%s", label, "gnu");
   if (0 == rd_count)
   {
     tm = GTK_TREE_MODEL (ls);
     if (gtk_tree_model_get_iter_first (tm, &iter))
       do
-	{
-	  gtk_tree_model_get (tm, &iter,
-			      0, &id,
-			      -1);
-	  if (0 == strcmp (id, label_gnu))
-	    {
-	      GNUNET_assert (gtk_list_store_remove (ls, &iter));
-	      g_free (id);
-	      g_free (label_gnu);
-	      return;
-	    }
-	  g_free (id);
-	}
-      while (gtk_tree_model_iter_next (tm, &iter));
+      {
+        gtk_tree_model_get (tm, &iter, 0, &id, -1);
+        if (0 == strcmp (id, label_gnu))
+        {
+          GNUNET_assert (gtk_list_store_remove (ls, &iter));
+          g_free (id);
+          g_free (label_gnu);
+          return;
+        }
+        g_free (id);
+      } while (gtk_tree_model_iter_next (tm, &iter));
     GNUNET_break (0);
     return;
   }
-  gtk_list_store_insert_with_values (ls,
-				     &iter,
-				     -1,
-				     0, label_gnu,
-				     -1);
+  gtk_list_store_insert_with_values (ls, &iter, -1, 0, label_gnu, -1);
   g_free (label_gnu);
 }
 
@@ -646,28 +648,35 @@ monitor_zone_records (void *cls,
  */
 static void
 handle_sks_zone_identity (void *cls,
-			  struct GNUNET_IDENTITY_Ego *ego,
-			  void **ctx,
-			  const char *name)
+                          struct GNUNET_IDENTITY_Ego *ego,
+                          void **ctx,
+                          const char *name)
 {
   main_context.id_op = NULL;
 
   if (NULL == ego)
   {
-    GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-		_("No default ego specified for `fs-sks` service, will not enable namespace search.\n"));
+    GNUNET_log (
+      GNUNET_ERROR_TYPE_WARNING,
+      _ (
+        "No default ego specified for `fs-sks` service, will not enable namespace search.\n"));
     return;
   }
   main_context.sks_zone = GNUNET_new (struct GNUNET_CRYPTO_EcdsaPrivateKey);
   *main_context.sks_zone = *GNUNET_IDENTITY_ego_get_private_key (ego);
-  gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_label")));
-  gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_combobox")));
+  gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_label")));
+  gtk_widget_show (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_combobox")));
   main_context.zm = GNUNET_NAMESTORE_zone_monitor_start (main_context.cfg,
-							 main_context.sks_zone,
+                                                         main_context.sks_zone,
                                                          GNUNET_YES,
-							 &monitor_zone_records,
-							 NULL,
-							 NULL);
+                                                         &monitor_zone_error,
+                                                         NULL,
+                                                         &monitor_zone_records,
+                                                         NULL,
+                                                         &monitor_zone_sync,
+                                                         NULL);
 }
 
 
@@ -676,10 +685,9 @@ handle_sks_zone_identity (void *cls,
  * is initialized.  Initializes up GTK and Glade.
  *
  * @param cls handle to the main loop (`struct GNUNET_GTK_MainLoop`)
- * @param tc scheduler context, unused
  */
 static void
-run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
+run (void *cls)
 {
   unsigned long long dl_parallel;
   unsigned long long req_parallel;
@@ -695,36 +703,68 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
     return;
   main_context.builder = GNUNET_GTK_main_loop_get_builder (ml);
   main_context.cfg = GNUNET_GTK_main_loop_get_configuration (ml);
-  main_context.search_ns_treestore = GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_treestore"));
-  main_context.main_window = GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"));
-  main_context.main_window = GNUNET_GTK_plug_me ("GNUNET_FS_GTK_PLUG",
-                                                 main_context.main_window);
-  main_context.ns_selector_treeview = GTK_TREE_VIEW (GNUNET_FS_GTK_get_main_window_object ("namespace_selector_treeview"));
-  main_context.ns_selector_window = GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("namespace_selector_window"));
-  main_context.ns_dropdown_button = GTK_TOGGLE_BUTTON (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_dropdown_button"));
-  main_context.search_ns_label = GTK_LABEL (GNUNET_FS_GTK_get_main_window_object ("main_window_search_selected_namespace_label"));
+  main_context.search_ns_treestore =
+    GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_namespace_treestore"));
+  main_context.main_window = GTK_WIDGET (
+    GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"));
+  main_context.main_window =
+    GNUNET_GTK_plug_me ("GNUNET_FS_GTK_PLUG", main_context.main_window);
+  main_context.ns_selector_treeview = GTK_TREE_VIEW (
+    GNUNET_FS_GTK_get_main_window_object ("namespace_selector_treeview"));
+  main_context.ns_selector_window = GTK_WIDGET (
+    GNUNET_FS_GTK_get_main_window_object ("namespace_selector_window"));
+  main_context.ns_dropdown_button =
+    GTK_TOGGLE_BUTTON (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_namespace_dropdown_button"));
+  main_context.search_ns_label =
+    GTK_LABEL (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_selected_namespace_label"));
 
-  main_context.search_entry = GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
+  main_context.search_entry = GTK_ENTRY (
+    GNUNET_FS_GTK_get_main_window_object ("main_window_search_entry"));
 
-  downloads_treestore = GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_file_sharing_downloads_tree_store"));
-  main_context.anonymity_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_search_anonymity_combobox"));
-  main_context.anonymity_level_liststore = GTK_LIST_STORE (GNUNET_FS_GTK_get_main_window_object ("anonymity_level_liststore"));
+  downloads_treestore = GTK_TREE_STORE (GNUNET_FS_GTK_get_main_window_object (
+    "GNUNET_GTK_file_sharing_downloads_tree_store"));
+  main_context.anonymity_combo =
+    GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_anonymity_combobox"));
+  main_context.anonymity_level_liststore = GTK_LIST_STORE (
+    GNUNET_FS_GTK_get_main_window_object ("anonymity_level_liststore"));
 
-  main_context.preview_image = GTK_IMAGE (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window_preview_image"));
-  main_context.md_liststore = GTK_LIST_STORE (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_meta_data_list_store"));
-  main_context.md_treeview = GTK_TREE_VIEW (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window_metadata_treeview"));
+  main_context.preview_image = GTK_IMAGE (GNUNET_FS_GTK_get_main_window_object (
+    "GNUNET_GTK_main_window_preview_image"));
+  main_context.md_liststore = GTK_LIST_STORE (
+    GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_meta_data_list_store"));
+  main_context.md_treeview =
+    GTK_TREE_VIEW (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_GTK_main_window_metadata_treeview"));
   main_context.ns_discovery_handle = NULL;
 
-  main_context.download_location_chooser = GTK_FILE_CHOOSER (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_search_frame_download_location_chooser"));
-  main_context.download_name_entry = GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_search_frame_download_filename_entry"));
-  main_context.download_anonymity_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_download_anonymity_combobox"));
-  main_context.download_recursive_checkbutton = GTK_CHECK_BUTTON (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_search_frame_download_recursive_checkbox"));
-  main_context.download_download_button = GTK_BUTTON (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_search_frame_download_download_button"));
-  main_context.download_panel = GTK_VBOX (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_search_frame_download_vbox"));
+  main_context.download_location_chooser =
+    GTK_FILE_CHOOSER (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_GTK_search_frame_download_location_chooser"));
+  main_context.download_name_entry =
+    GTK_ENTRY (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_GTK_search_frame_download_filename_entry"));
+  main_context.download_anonymity_combo =
+    GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_download_anonymity_combobox"));
+  main_context.download_recursive_checkbutton =
+    GTK_CHECK_BUTTON (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_GTK_search_frame_download_recursive_checkbox"));
+  main_context.download_download_button =
+    GTK_BUTTON (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_GTK_search_frame_download_download_button"));
+  main_context.download_panel = GTK_BOX (GNUNET_FS_GTK_get_main_window_object (
+    "GNUNET_GTK_search_frame_download_vbox"));
 
-  main_context.notebook = GTK_NOTEBOOK (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window_notebook"));
+  main_context.notebook = GTK_NOTEBOOK (
+    GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window_notebook"));
 
-  main_context.connection_indicator = GTK_IMAGE (GNUNET_FS_GTK_get_main_window_object ("GNUNET_FS_GTK_main_window_connection_indicator"));
+  main_context.connection_indicator =
+    GTK_IMAGE (GNUNET_FS_GTK_get_main_window_object (
+      "GNUNET_FS_GTK_main_window_connection_indicator"));
 
   GNUNET_GTK_set_icon_search_path ();
   GNUNET_GTK_setup_nls ();
@@ -738,22 +778,32 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
 
   /* setup main window */
   maximized = GNUNET_CONFIGURATION_get_value_yesno (main_context.cfg,
-						    "gnunet-fs-gtk",
+                                                    "gnunet-fs-gtk",
                                                     "MAIN_WINDOW_MAXIMIZED");
   if (GNUNET_SYSERR == maximized)
     maximized = GNUNET_YES;
-  if ( (GNUNET_NO == maximized) &&
-       (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-							    "MAIN_WINDOW_X", &window_x)) &&
-       (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-							    "MAIN_WINDOW_Y", &window_y)) &&
-       (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-							    "MAIN_WINDOW_WIDTH", &window_width)) &&
-       (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-							    "MAIN_WINDOW_HEIGHT", &window_height)) )
+  if ((GNUNET_NO == maximized) &&
+      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                                           "gnunet-fs-gtk",
+                                                           "MAIN_WINDOW_X",
+                                                           &window_x)) &&
+      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                                           "gnunet-fs-gtk",
+                                                           "MAIN_WINDOW_Y",
+                                                           &window_y)) &&
+      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                                           "gnunet-fs-gtk",
+                                                           "MAIN_WINDOW_WIDTH",
+                                                           &window_width)) &&
+      (GNUNET_OK == GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                                           "gnunet-fs-gtk",
+                                                           "MAIN_WINDOW_HEIGHT",
+                                                           &window_height)))
   {
     gtk_window_move (GTK_WINDOW (main_context.main_window), window_x, window_y);
-    gtk_window_resize (GTK_WINDOW (main_context.main_window), window_width, window_height);
+    gtk_window_resize (GTK_WINDOW (main_context.main_window),
+                       window_width,
+                       window_height);
   }
   else
   {
@@ -762,29 +812,34 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
   }
 
   /* Allow multiple selection in metadata view; */
-  /* FIXME-GTK3: this can be done within (modern versions of) glade */
-  gtk_tree_selection_set_mode (gtk_tree_view_get_selection (main_context.md_treeview),
+  /* FIXME-GTK3: this can be done within (modern versions of) glade
+     (However, this needs GTK >= 3.2, we currently target 3.0) */
+  gtk_tree_selection_set_mode (gtk_tree_view_get_selection (
+                                 main_context.md_treeview),
                                GTK_SELECTION_MULTIPLE);
-  if (NULL == getenv ("GNUNET_FS_GTK_PLUG"))
-    GNUNET_GTK_tray_icon_create (ml,
-                                 GTK_WINDOW (main_context.main_window),
-                                 "gnunet-fs-gtk",
-                                 "gnunet-fs-gtk");
 
   /* FIXME: should these '1's be here? Maybe better to put them into
    * default config files?
    */
-  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-      "MAX_PARALLEL_DOWNLOADS", &dl_parallel))
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                             "gnunet-fs-gtk",
+                                             "MAX_PARALLEL_DOWNLOADS",
+                                             &dl_parallel))
     dl_parallel = DEFAULT_MAX_PARALLEL_DOWNLOADS;
-  if (GNUNET_OK != GNUNET_CONFIGURATION_get_value_number (main_context.cfg, "gnunet-fs-gtk",
-      "MAX_PARALLEL_REQUESTS", &req_parallel))
+  if (GNUNET_OK !=
+      GNUNET_CONFIGURATION_get_value_number (main_context.cfg,
+                                             "gnunet-fs-gtk",
+                                             "MAX_PARALLEL_REQUESTS",
+                                             &req_parallel))
     req_parallel = DEFAULT_MAX_PARALLEL_REQUESTS;
 
   /* initialize file-sharing */
-  fs = GNUNET_FS_start (main_context.cfg, "gnunet-fs-gtk",
-			&GNUNET_GTK_fs_event_handler, NULL,
-			GNUNET_FS_FLAGS_PERSISTENCE | GNUNET_FS_FLAGS_DO_PROBES,
+  fs = GNUNET_FS_start (main_context.cfg,
+                        "gnunet-fs-gtk",
+                        &GNUNET_GTK_fs_event_handler,
+                        NULL,
+                        GNUNET_FS_FLAGS_PERSISTENCE | GNUNET_FS_FLAGS_DO_PROBES,
                         GNUNET_FS_OPTIONS_DOWNLOAD_PARALLELISM,
                         (unsigned int) dl_parallel,
                         GNUNET_FS_OPTIONS_REQUEST_PARALLELISM,
@@ -795,25 +850,29 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
     GNUNET_GTK_main_loop_quit (cls);
     return;
   }
-  arm = GNUNET_ARM_connect (main_context.cfg, &arm_connection_state_change, &main_context);
-  armon = GNUNET_ARM_monitor (main_context.cfg, service_status_change, &main_context);
+  arm = GNUNET_ARM_connect (main_context.cfg,
+                            &arm_connection_state_change,
+                            &main_context);
+  armon = GNUNET_ARM_monitor_start (main_context.cfg,
+                                    &service_status_change,
+                                    &main_context);
   main_context.gns = GNUNET_GNS_connect (main_context.cfg);
-  main_context.identity = GNUNET_IDENTITY_connect (main_context.cfg, NULL, NULL);
+  main_context.identity =
+    GNUNET_IDENTITY_connect (main_context.cfg, NULL, NULL);
   main_context.id_op = GNUNET_IDENTITY_get (main_context.identity,
-					    "fs-sks",
-					    &handle_sks_zone_identity,
-					    NULL);
+                                            "fs-sks",
+                                            &handle_sks_zone_identity,
+                                            NULL);
 #if HAVE_LIBUNIQUE
   unique_app_watch_window (unique_app, GTK_WINDOW (main_context.main_window));
-  g_signal_connect (unique_app, "message-received",
-		    G_CALLBACK (unique_app_message_cb), &main_context);
+  g_signal_connect (unique_app,
+                    "message-received",
+                    G_CALLBACK (unique_app_message_cb),
+                    &main_context);
 #endif
   /* make GUI visible */
-  if (!tray_only)
-  {
-    gtk_widget_show (main_context.main_window);
-    gtk_window_present (GTK_WINDOW (main_context.main_window));
-  }
+  gtk_widget_show (main_context.main_window);
+  gtk_window_present (GTK_WINDOW (main_context.main_window));
 
   {
     char *const *argv;
@@ -823,19 +882,13 @@ run (void *cls, const struct GNUNET_SCHEDULER_TaskContext *tc)
     GNUNET_GTK_main_loop_get_args (ml, &argc, &argv);
 
     for (i = 0; i < argc; i++)
-      {
-	if (GNUNET_OK !=
-	    GNUNET_FS_GTK_handle_uri_string (argv[i],
-					     1 /* anonymity level */))
-	  fprintf (stderr,
-		   "Invalid URI `%s'\n",
-		   argv[i]);
-      }
+    {
+      if (GNUNET_OK !=
+          GNUNET_FS_GTK_handle_uri_string (argv[i], 1 /* anonymity level */))
+        fprintf (stderr, "Invalid URI `%s'\n", argv[i]);
+    }
   }
-
-
-  GNUNET_SCHEDULER_add_delayed (GNUNET_TIME_UNIT_FOREVER_REL,
-				&shutdown_task, NULL);
+  GNUNET_SCHEDULER_add_shutdown (&shutdown_task, NULL);
 }
 
 
@@ -843,11 +896,7 @@ int
 main (int argc, char **argv)
 {
   static struct GNUNET_GETOPT_CommandLineOption options[] = {
-    {'t', "tray", NULL,
-     gettext_noop ("start in tray mode"), 0,
-     &GNUNET_GETOPT_set_one, &tray_only},
-    GNUNET_GETOPT_OPTION_END
-  };
+    GNUNET_GETOPT_OPTION_END};
 #if HAVE_LIBUNIQUE
   int arge;
 
@@ -857,20 +906,16 @@ main (int argc, char **argv)
   {
     UniqueResponse response;
 
-    arge = GNUNET_GETOPT_run ("gnunet-fs-gtk",
-			      options,
-			      argc, argv);
+    arge = GNUNET_GETOPT_run ("gnunet-fs-gtk", options, argc, argv);
     response = unique_app_send_message (unique_app, UNIQUE_ACTIVATE, NULL);
     while (arge < argc)
     {
       UniqueMessageData *msg;
 
       msg = unique_message_data_new ();
-      unique_message_data_set_text (msg, argv[arge], strlen (argv[arge])+1);
+      unique_message_data_set_text (msg, argv[arge], strlen (argv[arge]) + 1);
       if (UNIQUE_RESPONSE_OK == response)
-	response = unique_app_send_message (unique_app,
-					    UNIQUE_OPEN,
-					    msg);
+        response = unique_app_send_message (unique_app, UNIQUE_OPEN, msg);
       unique_message_data_free (msg);
       arge++;
     }
@@ -882,11 +927,12 @@ main (int argc, char **argv)
 #endif
   if (GNUNET_OK !=
       GNUNET_GTK_main_loop_start ("gnunet-fs-gtk",
-				  "GTK GUI for GNUnet",
-				  argc, argv,
-				  options,
+                                  "GTK GUI for GNUnet",
+                                  argc,
+                                  argv,
+                                  options,
                                   "gnunet_fs_gtk_main_window.glade",
-				  &run))
+                                  &run))
   {
 #if HAVE_LIBUNIQUE
     g_object_unref (unique_app);
