@@ -1,6 +1,6 @@
 /*
      This file is part of GNUnet.
-     (C) 2010, 2011, 2012 Christian Grothoff (and other contributing authors)
+     Copyright (C) 2010, 2011, 2012 GNUnet e.V.
 
      GNUnet is free software; you can redistribute it and/or modify
      it under the terms of the GNU General Public License as published
@@ -14,8 +14,8 @@
 
      You should have received a copy of the GNU General Public License
      along with GNUnet; see the file COPYING.  If not, write to the
-     Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-     Boston, MA 02111-1307, USA.
+     Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+     Boston, MA 02110-1301, USA.
 */
 
 /**
@@ -56,11 +56,11 @@ struct DownloadAsDialogContext
   char *dirname;
 
   /**
-   * Set to GNUNET_YES if pressing "Save" button should initiate the download
-   * right away, set to GNUNET_NO if it should only change directory and file
+   * Set to #GNUNET_YES if pressing "Save" button should initiate the download
+   * right away, set to #GNUNET_NO if it should only change directory and file
    * names on the download panel.
-   * Popup menu sets it to GNUNET_YES, download panel "Change name" button sets
-   * it to GNUNET_NO.
+   * Popup menu sets it to #GNUNET_YES, download panel "Change name" button sets
+   * it to #GNUNET_NO.
    */
   int download_directly;
 };
@@ -79,7 +79,9 @@ clean_up_download_as_context (struct DownloadAsDialogContext *dlc)
   if (NULL != dlc->dirname)
   {
     if (0 != RMDIR (dlc->dirname))
-      GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_WARNING, "rmdir", dlc->dirname);
+      GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_WARNING,
+                                "rmdir",
+                                dlc->dirname);
     GNUNET_free (dlc->dirname);
   }
   GNUNET_free (dlc);
@@ -109,13 +111,14 @@ GNUNET_FS_GTK_free_download_entry (struct DownloadEntry *de)
   if (NULL != de->rr)
   {
     path = gtk_tree_row_reference_get_path (de->rr);
-    GNUNET_assert (gtk_tree_model_get_iter (GTK_TREE_MODEL (downloads_treestore),
-                                            &iter, path));
+    GNUNET_assert (
+      gtk_tree_model_get_iter (GTK_TREE_MODEL (downloads_treestore),
+                               &iter,
+                               path));
     gtk_tree_path_free (path);
     gtk_tree_row_reference_free (de->rr);
     de->rr = NULL;
-    gtk_tree_store_remove (downloads_treestore,
-                           &iter);
+    gtk_tree_store_remove (downloads_treestore, &iter);
   }
   GNUNET_free (de);
 }
@@ -130,7 +133,8 @@ GNUNET_FS_GTK_free_download_entry (struct DownloadEntry *de)
  * @return always FALSE (destroy the window)
  */
 gboolean
-GNUNET_GTK_save_as_dialog_delete_event_cb (GtkWidget * widget, GdkEvent * event,
+GNUNET_GTK_save_as_dialog_delete_event_cb (GtkWidget *widget,
+                                           GdkEvent *event,
                                            gpointer user_data)
 {
   struct DownloadAsDialogContext *dlc = user_data;
@@ -150,8 +154,8 @@ GNUNET_GTK_save_as_dialog_delete_event_cb (GtkWidget * widget, GdkEvent * event,
  * @param user_data the 'structDownloadAsDialogContext' of the dialog
  */
 void
-GNUNET_GTK_save_as_dialog_response_cb (GtkDialog * dialog,
-				       gint response_id,
+GNUNET_GTK_save_as_dialog_response_cb (GtkDialog *dialog,
+                                       gint response_id,
                                        gpointer user_data)
 {
   struct DownloadAsDialogContext *dlc = user_data;
@@ -168,20 +172,19 @@ GNUNET_GTK_save_as_dialog_response_cb (GtkDialog * dialog,
   }
   GNUNET_free_non_null (de->filename);
   de->filename =
-      GNUNET_GTK_filechooser_get_filename_utf8 (GTK_FILE_CHOOSER (dlc->dialog));
-  cb = GTK_TOGGLE_BUTTON (gtk_builder_get_object
-			  (dlc->builder, "GNUNET_GTK_save_as_recursive_check_button"));
+    GNUNET_GTK_filechooser_get_filename_utf8 (GTK_FILE_CHOOSER (dlc->dialog));
+  cb = GTK_TOGGLE_BUTTON (
+    gtk_builder_get_object (dlc->builder,
+                            "GNUNET_GTK_save_as_recursive_check_button"));
   if (dlc->download_directly)
   {
     de->is_recursive =
-        (TRUE ==
-         gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cb))) ? GNUNET_YES :
-        GNUNET_NO;
-    de->anonymity =
-      (uint32_t) gtk_spin_button_get_value (GTK_SPIN_BUTTON
-					    (gtk_builder_get_object
-					     (dlc->builder,
-					      "GNUNET_GTK_save_as_dialog_anonymity_spin_button")));
+      (TRUE == gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (cb)))
+        ? GNUNET_YES
+        : GNUNET_NO;
+    de->anonymity = (uint32_t) gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+      gtk_builder_get_object (dlc->builder,
+                              "GNUNET_GTK_save_as_dialog_anonymity_spin_button")));
   }
   gtk_widget_destroy (GTK_WIDGET (dialog));
   if (dlc->download_directly)
@@ -189,7 +192,9 @@ GNUNET_GTK_save_as_dialog_response_cb (GtkDialog * dialog,
   else if (de->sr != NULL && de->sr->tab != NULL && de->sr->rr != NULL)
   {
     /* Update download panel */
-    GNUNET_FS_GTK_set_item_downloaded_name (de->sr->tab->ts, de->sr->rr, de->filename);
+    GNUNET_FS_GTK_set_item_downloaded_name (de->sr->tab->ts,
+                                            de->sr->rr,
+                                            de->filename);
     GNUNET_FS_GTK_free_download_entry (de);
   }
   /* we were successful, do not remove the directory (if we created one) */
@@ -198,7 +203,9 @@ GNUNET_GTK_save_as_dialog_response_cb (GtkDialog * dialog,
   clean_up_download_as_context (dlc);
 }
 
-/* FIXME: implement handling for corner cases:
+
+/*
+** FIXME: implement handling for corner cases:
  * A) Selection changes in search tab while SaveAs dialog is open.
  *    If it's in direct download mode, ignore that; otherwise destroy the dialog.
  * B) Download! is pressed in download panel (or the search result is otherwise
@@ -216,8 +223,7 @@ open_saveas_dialog (struct DownloadEntry *de, int download_directly)
   dlc->de = de;
   dlc->download_directly = download_directly;
   dlc->builder =
-    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_download_as_dialog.glade",
-				dlc);
+    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_download_as_dialog.glade", dlc);
   if (NULL == dlc->builder)
   {
     GNUNET_break (0);
@@ -225,20 +231,22 @@ open_saveas_dialog (struct DownloadEntry *de, int download_directly)
     GNUNET_free (dlc);
     return;
   }
-  dlc->dialog = GTK_WIDGET (gtk_builder_get_object
-			    (dlc->builder, "GNUNET_GTK_save_as_dialog"));
+  dlc->dialog = GTK_WIDGET (
+    gtk_builder_get_object (dlc->builder, "GNUNET_GTK_save_as_dialog"));
 
   /* Enable recursive button for directories and
      set recursive 'default' value based on what the 'dc' tells us */
-  cb = GTK_WIDGET (gtk_builder_get_object
-                   (dlc->builder, "GNUNET_GTK_save_as_recursive_check_button"));
-  hb = GTK_WIDGET (gtk_builder_get_object (dlc->builder, "GNUNET_GTK_save_as_dialog_options_hbox"));
+  cb = GTK_WIDGET (
+    gtk_builder_get_object (dlc->builder,
+                            "GNUNET_GTK_save_as_recursive_check_button"));
+  hb = GTK_WIDGET (
+    gtk_builder_get_object (dlc->builder,
+                            "GNUNET_GTK_save_as_dialog_options_hbox"));
   if (download_directly)
   {
     if (GNUNET_YES == de->is_directory)
       gtk_widget_set_sensitive (cb, TRUE);
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cb),
-				  de->is_recursive);
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (cb), de->is_recursive);
     gtk_widget_show (hb);
   }
   else
@@ -263,23 +271,25 @@ open_saveas_dialog (struct DownloadEntry *de, int download_directly)
     {
       if (GNUNET_OK != GNUNET_DISK_directory_create (dirname))
       {
-	GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_WARNING, "mkdir", dirname);
+        GNUNET_log_strerror_file (GNUNET_ERROR_TYPE_WARNING, "mkdir", dirname);
       }
       else
       {
-	dlc->dirname = dirname;
+        dlc->dirname = dirname;
       }
     }
-    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlc->dialog), dirname);
-    gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dlc->dialog), basename);
+    gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (dlc->dialog),
+                                         dirname);
+    gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dlc->dialog),
+                                       basename);
     if (NULL == dlc->dirname)
       GNUNET_free (dirname);
   }
-  gtk_dialog_set_default_response (GTK_DIALOG (dlc->dialog),
-				   GTK_RESPONSE_OK);
+  gtk_dialog_set_default_response (GTK_DIALOG (dlc->dialog), GTK_RESPONSE_OK);
   gtk_window_present (GTK_WINDOW (dlc->dialog));
 }
 
+
 /**
  * Open the 'save as' dialog for a download.  Calls the 'dc->cb'
  * continutation when the dialog is complete.  Will release the 'dc'
@@ -294,6 +304,7 @@ GNUNET_FS_GTK_open_download_as_dialog (struct DownloadEntry *de)
   open_saveas_dialog (de, GNUNET_YES);
 }
 
+
 /**
  * Open the 'save as' dialog for a download.  Calls the 'dc->cb'
  * continutation when the dialog is complete.  Will release the 'dc'
@@ -334,26 +345,30 @@ GNUNET_FS_GTK_download_context_start_download (struct DownloadEntry *de)
   {
     GNUNET_break (NULL !=
                   GNUNET_FS_download_start_from_search (fs,
-							de->sr->result,
+                                                        de->sr->result,
                                                         de->filename,
-                                                        NULL /* tempname */ ,
-                                                        0 /* offset */ ,
+                                                        NULL /* tempname */,
+                                                        0 /* offset */,
                                                         len,
-							de->anonymity, opt,
+                                                        de->anonymity,
+                                                        opt,
                                                         de));
   }
   else
   {
-    GNUNET_break (NULL !=
-                  GNUNET_FS_download_start (fs,
-					    de->uri,
-					    NULL /* meta data */,
-                                            de->filename, NULL /* tempname */ ,
-                                            0 /* offset */ ,
-                                            len,
-					    de->anonymity, opt,
-					    de,
-                                            (NULL != de->pde) ? de->pde->dc : NULL));
+    GNUNET_break (
+      NULL !=
+      GNUNET_FS_download_start (fs,
+                                de->uri,
+                                NULL /* meta data */,
+                                de->filename,
+                                NULL /* tempname */,
+                                0 /* offset */,
+                                len,
+                                de->anonymity,
+                                opt,
+                                de,
+                                (NULL != de->pde) ? de->pde->dc : NULL));
   }
 }
 
