@@ -32,7 +32,8 @@
 /**
  * How long until we decide a SKS namespace GNS lookup has failed?
  */
-#define LOOKUP_TIMEOUT GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 2)
+#define LOOKUP_TIMEOUT \
+  GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 2)
 
 
 /**
@@ -41,11 +42,9 @@
 static void
 beep ()
 {
-  gdk_display_beep
-    (gdk_screen_get_display
-     (gdk_window_get_screen
-      (gtk_widget_get_parent_window
-       (GTK_WIDGET (GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"))))));
+  gdk_display_beep (gdk_screen_get_display (
+    gdk_window_get_screen (gtk_widget_get_parent_window (GTK_WIDGET (
+      GNUNET_FS_GTK_get_main_window_object ("GNUNET_GTK_main_window"))))));
 }
 
 
@@ -56,12 +55,13 @@ beep ()
  * @param anonymity_level degree of anonymity to apply for the search
  */
 static void
-search_for_uri (struct GNUNET_FS_Uri *uri,
-		guint anonymity_level)
+search_for_uri (struct GNUNET_FS_Uri *uri, guint anonymity_level)
 {
   GNUNET_FS_search_start (GNUNET_FS_GTK_get_fs_handle (),
-			  uri, anonymity_level,
-                          GNUNET_FS_SEARCH_OPTION_NONE, NULL);
+                          uri,
+                          anonymity_level,
+                          GNUNET_FS_SEARCH_OPTION_NONE,
+                          NULL);
   GNUNET_FS_uri_destroy (uri);
 }
 
@@ -74,11 +74,10 @@ search_for_uri (struct GNUNET_FS_Uri *uri,
 void
 abort_search_lookup (struct SearchLookup *sl)
 {
-  struct GNUNET_GTK_MainWindowContext *main_ctx = GNUNET_FS_GTK_get_main_context ();
+  struct GNUNET_GTK_MainWindowContext *main_ctx =
+    GNUNET_FS_GTK_get_main_context ();
 
-  GNUNET_CONTAINER_DLL_remove (main_ctx->sl_head,
-			       main_ctx->sl_tail,
-			       sl);
+  GNUNET_CONTAINER_DLL_remove (main_ctx->sl_head, main_ctx->sl_tail, sl);
   if (NULL != sl->timeout_task)
   {
     GNUNET_SCHEDULER_cancel (sl->timeout_task);
@@ -107,7 +106,7 @@ timeout_search_lookup (void *cls)
 
   sl->timeout_task = NULL;
   GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-	      _("Failed to resolve namespace in time\n"));
+              _ ("Failed to resolve namespace in time\n"));
   abort_search_lookup (sl);
 }
 
@@ -122,15 +121,15 @@ timeout_search_lookup (void *cls)
  */
 static void
 handle_gns_result (void *cls,
-		   uint32_t rd_count,
-		   const struct GNUNET_GNSRECORD_Data *rd)
+                   uint32_t rd_count,
+                   const struct GNUNET_GNSRECORD_Data *rd)
 {
   struct SearchLookup *sl = cls;
   unsigned int i;
   struct GNUNET_FS_Uri *uri;
 
   sl->gns = NULL;
-  for (i=0;i<rd_count;i++)
+  for (i = 0; i < rd_count; i++)
   {
     if (GNUNET_GNSRECORD_TYPE_PKEY != rd[i].record_type)
       continue;
@@ -145,7 +144,7 @@ handle_gns_result (void *cls,
     return;
   }
   GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-	      _("Failed to resolve namespace in time\n"));
+              _ ("Failed to resolve namespace in time\n"));
   abort_search_lookup (sl);
 }
 
@@ -168,8 +167,10 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   char *emsg;
 
   /* get anonymity level */
-  if (!GNUNET_GTK_get_selected_anonymity_level
-      (main_ctx->builder, "main_window_search_anonymity_combobox", &anonymity_level))
+  if (! GNUNET_GTK_get_selected_anonymity_level (
+        main_ctx->builder,
+        "main_window_search_anonymity_combobox",
+        &anonymity_level))
   {
     GNUNET_break (0);
     return;
@@ -181,18 +182,18 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
     GtkTreeModel *mime_model;
     GtkTreeIter iter;
 
-    mime_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object
-				("main_window_search_mime_combobox"));
+    mime_combo = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_mime_combobox"));
     mime_model = gtk_combo_box_get_model (mime_combo);
     mime_keyword = NULL;
-    if ( (NULL != mime_model) &&
-	 gtk_combo_box_get_active_iter (mime_combo, &iter))
-      gtk_tree_model_get (mime_model, &iter,
+    if ((NULL != mime_model) &&
+        gtk_combo_box_get_active_iter (mime_combo, &iter))
+      gtk_tree_model_get (mime_model,
+                          &iter,
                           GNUNET_GTK_FS_MAIN_WINDOW_SEARCH_MIME_MC_MIME,
                           &mime_keyword,
                           -1);
-    if ( (NULL != mime_keyword) &&
-	 (0 == strcmp (mime_keyword, " ")) )
+    if ((NULL != mime_keyword) && (0 == strcmp (mime_keyword, " ")))
     {
       g_free (mime_keyword);
       mime_keyword = NULL;
@@ -201,13 +202,12 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   {
     GtkComboBox *namespace_box;
 
-    namespace_box = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object ("main_window_search_namespace_combobox"));
-    nsid = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (namespace_box))));
-    if ( (NULL != nsid) &&
-	 ( (0 == strcasecmp (nsid,
-			     "<none>")) ||
-	   (0 == strcasecmp (nsid,
-			     _("<none>"))) ) )
+    namespace_box = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+      "main_window_search_namespace_combobox"));
+    nsid = gtk_entry_get_text (
+      GTK_ENTRY (gtk_bin_get_child (GTK_BIN (namespace_box))));
+    if ((NULL != nsid) && ((0 == strcasecmp (nsid, "<none>")) ||
+                           (0 == strcasecmp (nsid, _ ("<none>")))))
       nsid = NULL;
   }
 
@@ -218,9 +218,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
     entry_keywords = gtk_entry_get_text (main_ctx->search_entry);
     if (NULL != mime_keyword)
     {
-      keywords = g_strdup_printf ("%s +%s",
-				  entry_keywords,
-				  mime_keyword);
+      keywords = g_strdup_printf ("%s +%s", entry_keywords, mime_keyword);
       g_free (mime_keyword);
     }
     else
@@ -230,26 +228,22 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   }
 
   /* build KSK/SKS URI */
-  if ( (NULL != nsid) &&
-       (0 < strlen (nsid)) )
+  if ((NULL != nsid) && (0 < strlen (nsid)))
   {
     sl = GNUNET_new (struct SearchLookup);
     sl->keywords = keywords;
     sl->anonymity_level = anonymity_level;
-    sl->timeout_task = GNUNET_SCHEDULER_add_delayed (LOOKUP_TIMEOUT,
-						     &timeout_search_lookup, sl);
-    GNUNET_CRYPTO_ecdsa_key_get_public (main_ctx->sks_zone,
-				      &pub_sks_zone);
+    sl->timeout_task =
+      GNUNET_SCHEDULER_add_delayed (LOOKUP_TIMEOUT, &timeout_search_lookup, sl);
+    GNUNET_CRYPTO_ecdsa_key_get_public (main_ctx->sks_zone, &pub_sks_zone);
     sl->gns = GNUNET_GNS_lookup (main_ctx->gns,
-				 nsid,
-				 &pub_sks_zone,
-				 GNUNET_GNSRECORD_TYPE_PKEY,
-				 GNUNET_NO,
-				 &handle_gns_result,
-				 sl);
-    GNUNET_CONTAINER_DLL_insert (main_ctx->sl_head,
-				 main_ctx->sl_tail,
-				 sl);
+                                 nsid,
+                                 &pub_sks_zone,
+                                 GNUNET_GNSRECORD_TYPE_PKEY,
+                                 GNUNET_NO,
+                                 &handle_gns_result,
+                                 sl);
+    GNUNET_CONTAINER_DLL_insert (main_ctx->sl_head, main_ctx->sl_tail, sl);
     return;
   }
 
@@ -258,8 +252,9 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
   if (NULL == uri)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-		_("Invalid keyword string `%s': %s"),
-		keywords, emsg);
+                _ ("Invalid keyword string `%s': %s"),
+                keywords,
+                emsg);
     g_free (keywords);
     GNUNET_free_non_null (emsg);
     return;
@@ -276,8 +271,7 @@ start_search (struct GNUNET_GTK_MainWindowContext *main_ctx)
  * @param user_data the main window context builder
  */
 void
-main_window_search_button_clicked_cb (GtkButton * button,
-				      gpointer user_data)
+main_window_search_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
 
@@ -295,8 +289,8 @@ main_window_search_button_clicked_cb (GtkButton * button,
  * @return FALSE if this was not ENTER, TRUE if it was
  */
 gboolean
-main_window_search_entry_key_press_event_cb (GtkWidget * widget,
-                                             GdkEventKey * event,
+main_window_search_entry_key_press_event_cb (GtkWidget *widget,
+                                             GdkEventKey *event,
                                              gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
@@ -363,11 +357,8 @@ abort_pseu_lookup (struct PseuLookupContext *lctx)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = lctx->main_ctx;
 
-  GNUNET_CONTAINER_DLL_remove (main_ctx->lctx_head,
-			       main_ctx->lctx_tail,
-			       lctx);
-  (void) GNUNET_SCHEDULER_add_now (&end_pseu_lookup,
-				   lctx);
+  GNUNET_CONTAINER_DLL_remove (main_ctx->lctx_head, main_ctx->lctx_tail, lctx);
+  (void) GNUNET_SCHEDULER_add_now (&end_pseu_lookup, lctx);
 }
 
 
@@ -382,9 +373,7 @@ abort_pseu_lookup (struct PseuLookupContext *lctx)
  * @param emsg NULL on success, otherwise an error message
  */
 static void
-store_continuation (void *cls,
-		    int32_t success,
-		    const char *emsg)
+store_continuation (void *cls, int32_t success, const char *emsg)
 {
   struct PseuLookupContext *lctx = cls;
 
@@ -392,8 +381,8 @@ store_continuation (void *cls,
   if (NULL != emsg)
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-		_("Failed to save record: %s\n"),
-		emsg);
+                _ ("Failed to save record: %s\n"),
+                emsg);
     beep ();
   }
   abort_pseu_lookup (lctx);
@@ -407,8 +396,7 @@ store_continuation (void *cls,
  * @param nick nickname to store the namespace under
  */
 static void
-save_pseudonym_with_nick (struct PseuLookupContext *lctx,
-			  const char *nick)
+save_pseudonym_with_nick (struct PseuLookupContext *lctx, const char *nick)
 {
   struct GNUNET_GNSRECORD_Data rd;
   struct GNUNET_GTK_MainWindowContext *main_ctx;
@@ -416,14 +404,12 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx,
   GNUNET_break (NULL == lctx->nick);
   lctx->nick = GNUNET_strdup (nick);
   /* again, show progress indicator, this should be fast though... */
-  lctx->progress_dialog_builder
-    = GNUNET_GTK_get_new_builder
-    ("gnunet_fs_gtk_pseu_progress_dialog.glade",
-     lctx);
-  lctx->progress_dialog
-    = GTK_WIDGET (gtk_builder_get_object
-		  (lctx->progress_dialog_builder,
-		   "GNUNET_FS_GTK_pseu_progress_dialog"));
+  lctx->progress_dialog_builder =
+    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_pseu_progress_dialog.glade",
+                                lctx);
+  lctx->progress_dialog =
+    GTK_WIDGET (gtk_builder_get_object (lctx->progress_dialog_builder,
+                                        "GNUNET_FS_GTK_pseu_progress_dialog"));
   /* show the window */
   gtk_window_present (GTK_WINDOW (lctx->progress_dialog));
   memset (&rd, 0, sizeof (rd));
@@ -436,10 +422,12 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx,
   lctx->namestore = GNUNET_NAMESTORE_connect (main_ctx->cfg);
   GNUNET_assert (NULL != lctx->namestore);
   lctx->qe = GNUNET_NAMESTORE_records_store (lctx->namestore,
-					     main_ctx->sks_zone,
-					     nick,
-					     1, &rd,
-					     &store_continuation, lctx);
+                                             main_ctx->sks_zone,
+                                             nick,
+                                             1,
+                                             &rd,
+                                             &store_continuation,
+                                             lctx);
 }
 
 
@@ -452,19 +440,18 @@ save_pseudonym_with_nick (struct PseuLookupContext *lctx,
  * @param user_data the `struct PseuLookupContext`
  */
 void
-GNUNET_GTK_enter_nick_window_execute_button_clicked_cb (GtkButton * button,
-							gpointer user_data)
+GNUNET_GTK_enter_nick_window_execute_button_clicked_cb (GtkButton *button,
+                                                        gpointer user_data)
 {
   struct PseuLookupContext *lctx = user_data;
   GtkEntry *entry;
   const char *nick;
 
-  entry = GTK_ENTRY (gtk_builder_get_object
-		     (lctx->nick_dialog_builder,
-		      "GNUNET_GTK_enter_nick_window_nick_entry"));
+  entry = GTK_ENTRY (
+    gtk_builder_get_object (lctx->nick_dialog_builder,
+                            "GNUNET_GTK_enter_nick_window_nick_entry"));
   nick = gtk_entry_get_text (entry);
-  if ( (NULL == nick) ||
-       (0 == strlen (nick) ))
+  if ((NULL == nick) || (0 == strlen (nick)))
   {
     GNUNET_break (0);
     abort_pseu_lookup (lctx);
@@ -486,17 +473,21 @@ GNUNET_GTK_enter_nick_window_execute_button_clicked_cb (GtkButton * button,
  */
 void
 GNUNET_GTK_enter_nick_window_nick_entry_changed_cb (GtkWidget *widget,
-						    gpointer user_data)
+                                                    gpointer user_data)
 {
   struct PseuLookupContext *lctx = user_data;
   const gchar *new_text;
-  GtkButton * button;
+  GtkButton *button;
 
   new_text = gtk_entry_get_text (GTK_ENTRY (widget));
-  button = GTK_BUTTON (gtk_builder_get_object (lctx->nick_dialog_builder,
-					       "GNUNET_GTK_enter_nick_window_execute_button"));
+  button = GTK_BUTTON (
+    gtk_builder_get_object (lctx->nick_dialog_builder,
+                            "GNUNET_GTK_enter_nick_window_execute_button"));
   gtk_widget_set_sensitive (GTK_WIDGET (button),
-			    (GNUNET_OK == GNUNET_DNSPARSER_check_label (new_text)) ? TRUE : FALSE);
+                            (GNUNET_OK ==
+                             GNUNET_DNSPARSER_check_label (new_text))
+                              ? TRUE
+                              : FALSE);
 }
 
 
@@ -508,8 +499,8 @@ GNUNET_GTK_enter_nick_window_nick_entry_changed_cb (GtkWidget *widget,
  * @param user_data the `struct PseuLookupContext`
  */
 void
-GNUNET_GTK_enter_nick_window_cancel_button_clicked_cb (GtkButton * button,
-						       gpointer user_data)
+GNUNET_GTK_enter_nick_window_cancel_button_clicked_cb (GtkButton *button,
+                                                       gpointer user_data)
 {
   struct PseuLookupContext *lctx = user_data;
 
@@ -527,10 +518,11 @@ static void
 ask_for_nickname (struct PseuLookupContext *lctx)
 {
   /* setup the dialog and get the widgets we need most */
-  lctx->nick_dialog_builder = GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_enter_nick_dialog.glade",
-							  lctx);
-  lctx->nick_dialog = GTK_WIDGET (gtk_builder_get_object (lctx->nick_dialog_builder,
-							      "GNUNET_GTK_enter_nick_window"));
+  lctx->nick_dialog_builder =
+    GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_enter_nick_dialog.glade", lctx);
+  lctx->nick_dialog =
+    GTK_WIDGET (gtk_builder_get_object (lctx->nick_dialog_builder,
+                                        "GNUNET_GTK_enter_nick_window"));
   /* show the window */
   gtk_window_present (GTK_WINDOW (lctx->nick_dialog));
 }
@@ -548,8 +540,8 @@ ask_for_nickname (struct PseuLookupContext *lctx)
  */
 static void
 lookup_finished (void *cls,
-		 uint32_t rd_count,
-		 const struct GNUNET_GNSRECORD_Data *rd)
+                 uint32_t rd_count,
+                 const struct GNUNET_GNSRECORD_Data *rd)
 {
   struct PseuLookupContext *lctx = cls;
   unsigned int i;
@@ -563,18 +555,17 @@ lookup_finished (void *cls,
     lctx->progress_dialog_builder = NULL;
     lctx->progress_dialog = NULL;
   }
-  for (i=0;i<rd_count;i++)
+  for (i = 0; i < rd_count; i++)
   {
     if (GNUNET_GNSRECORD_TYPE_NICK == rd[i].record_type)
     {
       nick = rd[i].data;
       if ('\0' != nick[rd[i].data_size - 1])
       {
-	GNUNET_break (0);
-	continue;
+        GNUNET_break (0);
+        continue;
       }
-      save_pseudonym_with_nick (lctx,
-				nick);
+      save_pseudonym_with_nick (lctx, nick);
       return;
     }
   }
@@ -592,7 +583,7 @@ lookup_finished (void *cls,
  */
 void
 GNUNET_FS_GTK_pseu_progress_dialog_cancel_button_clicked_cb (GtkButton *button,
-							     gpointer user_data)
+                                                             gpointer user_data)
 {
   struct PseuLookupContext *lctx = user_data;
 
@@ -620,8 +611,8 @@ GNUNET_FS_GTK_pseu_progress_dialog_cancel_button_clicked_cb (GtkButton *button,
  */
 gboolean
 GNUNET_GTK_enter_nick_window_delete_event_cb (GtkWidget *widget,
-					      GdkEvent * event,
-					      void *cls)
+                                              GdkEvent *event,
+                                              void *cls)
 {
   /* Don't allow GTK to kill the window, user must click execute or cancel */
   beep ();
@@ -639,8 +630,8 @@ GNUNET_GTK_enter_nick_window_delete_event_cb (GtkWidget *widget,
  */
 gboolean
 GNUNET_FS_GTK_pseu_progress_dialog_delete_event_cb (GtkWidget *widget,
-						    GdkEvent * event,
-						    void *cls)
+                                                    GdkEvent *event,
+                                                    void *cls)
 {
   /* Don't allow GTK to kill the window, until the search is finished */
   beep ();
@@ -656,8 +647,7 @@ GNUNET_FS_GTK_pseu_progress_dialog_delete_event_cb (GtkWidget *widget,
  * @param user_data the main window context builder
  */
 void
-GNUNET_FS_GTK_save_button_clicked_cb (GtkButton * button,
-				      gpointer user_data)
+GNUNET_FS_GTK_save_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
   struct GNUNET_GTK_MainWindowContext *main_ctx = user_data;
   GtkComboBox *widget;
@@ -673,14 +663,16 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton * button,
     return;
   }
   /* get anonymity level */
-  if (!GNUNET_GTK_get_selected_anonymity_level
-      (main_ctx->builder, "main_window_search_anonymity_combobox", &anonymity_level))
+  if (! GNUNET_GTK_get_selected_anonymity_level (
+        main_ctx->builder,
+        "main_window_search_anonymity_combobox",
+        &anonymity_level))
   {
     GNUNET_break (0);
     return;
   }
-  widget = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object
-		       ("main_window_search_namespace_combobox"));
+  widget = GTK_COMBO_BOX (GNUNET_FS_GTK_get_main_window_object (
+    "main_window_search_namespace_combobox"));
   text = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
   ret = GNUNET_GNSRECORD_zkey_to_pkey (text, &pkey);
   if (GNUNET_OK != ret)
@@ -691,26 +683,26 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton * button,
   lctx = GNUNET_new (struct PseuLookupContext);
   lctx->pkey = pkey;
   lctx->main_ctx = main_ctx;
-  GNUNET_CONTAINER_DLL_insert (main_ctx->lctx_head,
-			       main_ctx->lctx_tail,
-			       lctx);
+  GNUNET_CONTAINER_DLL_insert (main_ctx->lctx_head, main_ctx->lctx_tail, lctx);
 
   if (0 == anonymity_level)
   {
     /* setup the dialog and get the widgets we need most */
-    lctx->progress_dialog_builder = GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_pseu_progress_dialog.glade",
-								lctx);
-    lctx->progress_dialog = GTK_WIDGET (gtk_builder_get_object (lctx->progress_dialog_builder,
-								"GNUNET_FS_GTK_pseu_progress_dialog"));
+    lctx->progress_dialog_builder =
+      GNUNET_GTK_get_new_builder ("gnunet_fs_gtk_pseu_progress_dialog.glade",
+                                  lctx);
+    lctx->progress_dialog = GTK_WIDGET (
+      gtk_builder_get_object (lctx->progress_dialog_builder,
+                              "GNUNET_FS_GTK_pseu_progress_dialog"));
     /* show the window */
     gtk_window_present (GTK_WINDOW (lctx->progress_dialog));
     lctx->lr = GNUNET_GNS_lookup (main_ctx->gns,
-				  GNUNET_GNS_EMPTY_LABEL_AT,
-				  &pkey,
-				  GNUNET_GNSRECORD_TYPE_NICK,
-				  GNUNET_NO,
-				  &lookup_finished,
-				  lctx);
+                                  GNUNET_GNS_EMPTY_LABEL_AT,
+                                  &pkey,
+                                  GNUNET_GNSRECORD_TYPE_NICK,
+                                  GNUNET_NO,
+                                  &lookup_finished,
+                                  lctx);
   }
   else
   {
@@ -719,8 +711,7 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton * button,
     ask_for_nickname (lctx);
   }
   /* do not allow save again just yet */
-  gtk_widget_set_sensitive (GTK_WIDGET (button),
-			    FALSE);
+  gtk_widget_set_sensitive (GTK_WIDGET (button), FALSE);
 }
 
 
@@ -733,7 +724,7 @@ GNUNET_FS_GTK_save_button_clicked_cb (GtkButton * button,
  */
 void
 main_window_search_namespace_combobox_changed_cb (GtkComboBox *widget,
-						  gpointer user_data)
+                                                  gpointer user_data)
 {
   GtkButton *button;
   const gchar *text;
@@ -742,12 +733,12 @@ main_window_search_namespace_combobox_changed_cb (GtkComboBox *widget,
 
   text = gtk_entry_get_text (GTK_ENTRY (gtk_bin_get_child (GTK_BIN (widget))));
   ret = GNUNET_GNSRECORD_zkey_to_pkey (text, &pkey);
-  button = GTK_BUTTON (GNUNET_FS_GTK_get_main_window_object
-		       ("GNUNET_FS_GTK_save_button"));
+  button = GTK_BUTTON (
+    GNUNET_FS_GTK_get_main_window_object ("GNUNET_FS_GTK_save_button"));
   gtk_widget_set_visible (GTK_WIDGET (button),
-			  (GNUNET_OK == ret) ? TRUE : FALSE);
+                          (GNUNET_OK == ret) ? TRUE : FALSE);
   gtk_widget_set_sensitive (GTK_WIDGET (button),
-			    (GNUNET_OK == ret) ? TRUE : FALSE);
+                            (GNUNET_OK == ret) ? TRUE : FALSE);
 }
 
 
