@@ -36,7 +36,7 @@
  */
 static void
 GNS_edit_dialog_soa_contact_email_entry_changed_cb (GtkEditable *entry,
-						    gpointer user_data)
+                                                    gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -53,7 +53,7 @@ GNS_edit_dialog_soa_contact_email_entry_changed_cb (GtkEditable *entry,
  */
 static void
 GNS_edit_dialog_soa_source_host_entry_changed_cb (GtkEditable *entry,
-						  gpointer user_data)
+                                                  gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -71,9 +71,7 @@ GNS_edit_dialog_soa_source_host_entry_changed_cb (GtkEditable *entry,
  * @param builder the edit dialog's builder
  */
 static void
-soa_load (void *cls,
-        gchar *n_value,
-        GtkBuilder *builder)
+soa_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
   char soa_rname[253 + 1];
   char soa_mname[253 + 1];
@@ -94,37 +92,39 @@ soa_load (void *cls,
                    &soa_min))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Unable to parse SOA record `%s'\n"),
+                _ ("Unable to parse SOA record `%s'\n"),
                 n_value);
     return;
   }
   /* set SOA record */
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_soa_source_host_entry")),
-                      soa_rname);
-  gtk_entry_set_text (GTK_ENTRY (gtk_builder_get_object (builder,
-                                                         "edit_dialog_soa_contact_email_entry")),
-                      soa_mname);
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_soa_serial_number_spinbutton")),
-     soa_serial);
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_soa_refresh_time_spinbutton")),
-     soa_refresh);
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_soa_retry_time_spinbutton")),
-     soa_retry);
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_soa_expire_time_spinbutton")),
-     soa_expire);
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_soa_minimum_ttl_spinbutton")),
-     soa_min);
+  gtk_entry_set_text (
+    GTK_ENTRY (
+      gtk_builder_get_object (builder, "edit_dialog_soa_source_host_entry")),
+    soa_rname);
+  gtk_entry_set_text (
+    GTK_ENTRY (
+      gtk_builder_get_object (builder, "edit_dialog_soa_contact_email_entry")),
+    soa_mname);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
+                               builder,
+                               "edit_dialog_soa_serial_number_spinbutton")),
+                             soa_serial);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
+                               builder,
+                               "edit_dialog_soa_refresh_time_spinbutton")),
+                             soa_refresh);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
+                               builder,
+                               "edit_dialog_soa_retry_time_spinbutton")),
+                             soa_retry);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
+                               builder,
+                               "edit_dialog_soa_expire_time_spinbutton")),
+                             soa_expire);
+  gtk_spin_button_set_value (GTK_SPIN_BUTTON (gtk_builder_get_object (
+                               builder,
+                               "edit_dialog_soa_minimum_ttl_spinbutton")),
+                             soa_min);
 }
 
 
@@ -137,8 +137,7 @@ soa_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-soa_store (void *cls,
-         GtkBuilder *builder)
+soa_store (void *cls, GtkBuilder *builder)
 {
   GtkEntry *entry;
   const gchar *source_host;
@@ -150,25 +149,30 @@ soa_store (void *cls,
   unsigned int soa_min;
   char *result;
 
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_soa_source_host_entry"));
+  entry = GTK_ENTRY (
+    gtk_builder_get_object (builder, "edit_dialog_soa_source_host_entry"));
   source_host = gtk_entry_get_text (entry);
-  entry = GTK_ENTRY (gtk_builder_get_object (builder,
-                                             "edit_dialog_soa_contact_email_entry"));
+  entry = GTK_ENTRY (
+    gtk_builder_get_object (builder, "edit_dialog_soa_contact_email_entry"));
   contact_email = gtk_entry_get_text (entry);
-  soa_serial = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                                                   "edit_dialog_soa_serial_number_spinbutton")));
-  soa_refresh = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                                                    "edit_dialog_soa_refresh_time_spinbutton")));
-  soa_retry = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                                                  "edit_dialog_soa_retry_time_spinbutton")));
-  soa_expire = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                                                   "edit_dialog_soa_expire_time_spinbutton")));
-  soa_min = gtk_spin_button_get_value (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                                                                "edit_dialog_soa_minimum_ttl_spinbutton")));
+  soa_serial = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder,
+                            "edit_dialog_soa_serial_number_spinbutton")));
+  soa_refresh = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder,
+                            "edit_dialog_soa_refresh_time_spinbutton")));
+  soa_retry = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder, "edit_dialog_soa_retry_time_spinbutton")));
+  soa_expire = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder,
+                            "edit_dialog_soa_expire_time_spinbutton")));
+  soa_min = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder,
+                            "edit_dialog_soa_minimum_ttl_spinbutton")));
   GNUNET_asprintf (&result,
                    "rname=%s mname=%s %lu,%lu,%lu,%lu,%lu",
-                   source_host, contact_email,
+                   source_host,
+                   contact_email,
                    soa_serial,
                    soa_refresh,
                    soa_retry,
@@ -190,29 +194,26 @@ soa_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-soa_validate (void *cls,
-            GtkBuilder *builder)
+soa_validate (void *cls, GtkBuilder *builder)
 {
   GtkEditable *entry;
   const gchar *preedit;
 
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_soa_source_host_entry")),
+  entry = GTK_EDITABLE (
+    gtk_builder_get_object (builder, "edit_dialog_soa_source_host_entry")),
   preedit = gtk_editable_get_chars (entry, 0, -1);
-  if ( (NULL == preedit) ||
-       (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)) )
+  if ((NULL == preedit) || (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)))
     return GNUNET_SYSERR;
   /* check for '@' in the e-mail --- required format uses "." instead! */
-  entry = GTK_EDITABLE (gtk_builder_get_object (builder,
-						"edit_dialog_soa_contact_email_entry")),
+  entry = GTK_EDITABLE (
+    gtk_builder_get_object (builder, "edit_dialog_soa_contact_email_entry")),
   preedit = gtk_editable_get_chars (entry, 0, -1);
   /* E-mail is specified in the RFC also as a 'domain-name', hence
      we check above that it follows those conventions as well; the '@'
      is a common mistake, and while it should be illegal despite IDN,
      it feels better to check explicitly. */
-  if ( (NULL == preedit) ||
-       (NULL != strstr (preedit, "@")) ||
-       (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)) )
+  if ((NULL == preedit) || (NULL != strstr (preedit, "@")) ||
+      (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)))
     return GNUNET_SYSERR;
   return GNUNET_OK;
 }
@@ -229,13 +230,12 @@ libgnunet_plugin_gtk_namestore_soa_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "GNS_edit_dialog_soa_contact_email_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_soa_contact_email_entry_changed_cb) },
-    { "GNS_edit_dialog_soa_source_host_entry_changed_cb",
-      G_CALLBACK (GNS_edit_dialog_soa_source_host_entry_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"GNS_edit_dialog_soa_contact_email_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_soa_contact_email_entry_changed_cb)},
+     {"GNS_edit_dialog_soa_source_host_entry_changed_cb",
+      G_CALLBACK (GNS_edit_dialog_soa_source_host_entry_changed_cb)},
+     {NULL, NULL}};
 
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
   plugin->cls = env;
