@@ -42,8 +42,7 @@
  * @param user_data the plugin environment
  */
 static void
-tlsa_value_textbuffer_changed_cb (GtkTextBuffer *textbuffer,
-                                  gpointer user_data)
+tlsa_value_textbuffer_changed_cb (GtkTextBuffer *textbuffer, gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -93,8 +92,9 @@ edit_dialog_tlsa_usage_radiobutton_toggled_cb (GtkToggleButton *togglebutton,
  * @param user_data the plugin environment
  */
 static void
-edit_dialog_tlsa_matching_type_radiobutton_toggled_cb (GtkToggleButton *togglebutton,
-                                                       gpointer user_data)
+edit_dialog_tlsa_matching_type_radiobutton_toggled_cb (
+  GtkToggleButton *togglebutton,
+  gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
 
@@ -130,15 +130,13 @@ edit_dialog_protocol_combobox_changed_cb (GtkEditable *entry,
  * @return index of the selected button, -1 for none
  */
 static int
-get_selected_radio_value (GtkBuilder *builder,
-                          const char *const*button_names)
+get_selected_radio_value (GtkBuilder *builder, const char *const *button_names)
 {
   GtkToggleButton *b;
 
-  for (int i=0; NULL != button_names[i]; i++)
+  for (int i = 0; NULL != button_names[i]; i++)
   {
-    b = GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder,
-                                                   button_names[i]));
+    b = GTK_TOGGLE_BUTTON (gtk_builder_get_object (builder, button_names[i]));
     if (gtk_toggle_button_get_active (b))
       return i;
   }
@@ -150,36 +148,33 @@ get_selected_radio_value (GtkBuilder *builder,
  * NULL-terminated array with the names of the "usage" buttons,
  * in order to match the respective value in TLSA.
  */
-static const char *const usage_buttons[] = {
-  "edit_dialog_tlsa_usage_ca_radiobutton",
-  "edit_dialog_tlsa_usage_service_cert_radiobutton",
-  "edit_dialog_tlsa_usage_trust_anchor_radiobutton",
-  "edit_dialog_tlsa_usage_domain_issued_cert_radiobutton",
-  NULL
-};
+static const char *const usage_buttons[] =
+  {"edit_dialog_tlsa_usage_ca_radiobutton",
+   "edit_dialog_tlsa_usage_service_cert_radiobutton",
+   "edit_dialog_tlsa_usage_trust_anchor_radiobutton",
+   "edit_dialog_tlsa_usage_domain_issued_cert_radiobutton",
+   NULL};
 
 
 /**
  * NULL-terminated array with the names of the "selector" buttons,
  * in order to match the respective value in TLSA.
  */
-static const char *const selector_buttons[] = {
-  "edit_dialog_tlsa_selector_full_cert_radiobutton",
-  "edit_dialog_tlsa_selector_subject_public_key_radiobutton",
-  NULL
-};
+static const char *const selector_buttons[] =
+  {"edit_dialog_tlsa_selector_full_cert_radiobutton",
+   "edit_dialog_tlsa_selector_subject_public_key_radiobutton",
+   NULL};
 
 
 /**
  * NULL-terminated array with the names of the "matching type" buttons,
  * in order to match the respective value in TLSA.
  */
-static const char *const matching_type_buttons[] = {
-  "edit_dialog_tlsa_matching_type_full_contents_radiobutton",
-  "edit_dialog_tlsa_matching_type_sha256_radiobutton",
-  "edit_dialog_tlsa_matching_type_sha512_radiobutton",
-  NULL
-};
+static const char *const matching_type_buttons[] =
+  {"edit_dialog_tlsa_matching_type_full_contents_radiobutton",
+   "edit_dialog_tlsa_matching_type_sha256_radiobutton",
+   "edit_dialog_tlsa_matching_type_sha512_radiobutton",
+   NULL};
 
 
 /**
@@ -192,9 +187,7 @@ static const char *const matching_type_buttons[] = {
  * @param builder the edit dialog's builder
  */
 static void
-tlsa_load (void *cls,
-          gchar *n_value,
-          GtkBuilder *builder)
+tlsa_load (void *cls, gchar *n_value, GtkBuilder *builder)
 {
   unsigned int protocol;
   GtkComboBox *cb;
@@ -221,7 +214,7 @@ tlsa_load (void *cls,
                    cert_data))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Unable to parse (boxed) TLSA record `%s'\n"),
+                _ ("Unable to parse (boxed) TLSA record `%s'\n"),
                 n_value);
     return;
   }
@@ -230,62 +223,54 @@ tlsa_load (void *cls,
     GNUNET_break (0);
     return;
   }
-  gtk_spin_button_set_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_port_spinbutton")),
-     service);
-  cb = GTK_COMBO_BOX (gtk_builder_get_object (builder,
-                                              "edit_dialog_protocol_combobox"));
-  tm = GTK_TREE_MODEL (gtk_builder_get_object (builder,
-                                               "edit_dialog_protocol_liststore"));
-  if (gtk_tree_model_get_iter_first (tm,
-                                     &iter))
+  gtk_spin_button_set_value (
+    GTK_SPIN_BUTTON (
+      gtk_builder_get_object (builder, "edit_dialog_port_spinbutton")),
+    service);
+  cb = GTK_COMBO_BOX (
+    gtk_builder_get_object (builder, "edit_dialog_protocol_combobox"));
+  tm = GTK_TREE_MODEL (
+    gtk_builder_get_object (builder, "edit_dialog_protocol_liststore"));
+  if (gtk_tree_model_get_iter_first (tm, &iter))
   {
     do
     {
-      gtk_tree_model_get (tm,
-                          &iter,
-                          1, &protocol_at_iter,
-                          -1);
+      gtk_tree_model_get (tm, &iter, 1, &protocol_at_iter, -1);
       if (protocol_at_iter == protocol)
       {
-        gtk_combo_box_set_active_iter (cb,
-                                       &iter);
+        gtk_combo_box_set_active_iter (cb, &iter);
         break;
       }
-    }
-    while (gtk_tree_model_iter_next (tm,
-                                     &iter));
+    } while (gtk_tree_model_iter_next (tm, &iter));
   }
   switch (usage)
   {
   case 0: /* CA cert */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
+    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+                                    builder,
                                     "edit_dialog_tlsa_usage_ca_radiobutton")),
                                   TRUE);
     break;
   case 1: /* Entity cert */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_usage_service_cert_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (
+        gtk_builder_get_object (builder,
+                                "edit_dialog_tlsa_usage_service_cert_radiobutton")),
+      TRUE);
     break;
   case 2: /* Trust anchor */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_usage_trust_anchor_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (
+        gtk_builder_get_object (builder,
+                                "edit_dialog_tlsa_usage_trust_anchor_radiobutton")),
+      TRUE);
     break;
   case 3: /* Domain-issued cert */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_usage_domain_issued_cert_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+        builder,
+        "edit_dialog_tlsa_usage_domain_issued_cert_radiobutton")),
+      TRUE);
     break;
   default:
     GNUNET_break_op (0);
@@ -294,50 +279,47 @@ tlsa_load (void *cls,
   switch (selector)
   {
   case 0: /* full cert, binary */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_selector_full_cert_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (
+        gtk_builder_get_object (builder,
+                                "edit_dialog_tlsa_selector_full_cert_radiobutton")),
+      TRUE);
     break;
   case 1: /* full cert, DER */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_selector_subject_public_key_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+        builder,
+        "edit_dialog_tlsa_selector_subject_public_key_radiobutton")),
+      TRUE);
     break;
   }
   switch (matching_type)
   {
   case 0: /* exact match */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_matching_type_full_contents_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+        builder,
+        "edit_dialog_tlsa_matching_type_full_contents_radiobutton")),
+      TRUE);
     break;
   case 1: /* SHA-256 hash */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_matching_type_sha256_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+        builder,
+        "edit_dialog_tlsa_matching_type_sha256_radiobutton")),
+      TRUE);
     break;
   case 2: /* SHA-512 hash */
-    gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON
-                                  (gtk_builder_get_object
-                                   (builder,
-                                    "edit_dialog_tlsa_matching_type_sha512_radiobutton")),
-                                  TRUE);
+    gtk_toggle_button_set_active (
+      GTK_TOGGLE_BUTTON (gtk_builder_get_object (
+        builder,
+        "edit_dialog_tlsa_matching_type_sha512_radiobutton")),
+      TRUE);
     break;
   }
-  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW
-                                 (gtk_builder_get_object (builder,
-                                                          "edit_dialog_tlsa_value_textview")));
-  gtk_text_buffer_set_text (tb,
-                            cert_data,
-                            -1);
+  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (
+    gtk_builder_get_object (builder, "edit_dialog_tlsa_value_textview")));
+  gtk_text_buffer_set_text (tb, cert_data, -1);
 }
 
 
@@ -350,8 +332,7 @@ tlsa_load (void *cls,
  * @return record value as a string, as specified in the dialog
  */
 static gchar *
-tlsa_store (void *cls,
-            GtkBuilder *builder)
+tlsa_store (void *cls, GtkBuilder *builder)
 {
   unsigned int protocol;
   GtkComboBox *cb;
@@ -367,48 +348,34 @@ tlsa_store (void *cls,
   GtkTextIter ti_start;
   GtkTextIter ti_end;
 
-  service = gtk_spin_button_get_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (builder,
-                                              "edit_dialog_port_spinbutton")));
-  cb = GTK_COMBO_BOX (gtk_builder_get_object (builder,
-                                              "edit_dialog_protocol_combobox"));
-  if (! gtk_combo_box_get_active_iter (cb,
-                                       &iter))
+  service = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (builder, "edit_dialog_port_spinbutton")));
+  cb = GTK_COMBO_BOX (
+    gtk_builder_get_object (builder, "edit_dialog_protocol_combobox"));
+  if (! gtk_combo_box_get_active_iter (cb, &iter))
   {
     GNUNET_break (0);
     return NULL;
   }
-  tm = GTK_TREE_MODEL (gtk_builder_get_object (builder,
-                                               "edit_dialog_protocol_liststore"));
-  gtk_tree_model_get (tm,
-                      &iter,
-                      1, &protocol,
-                      -1);
-  usage = get_selected_radio_value (builder,
-                                    usage_buttons);
-  selector = get_selected_radio_value (builder,
-                                       selector_buttons);
-  matching_type = get_selected_radio_value (builder,
-                                            matching_type_buttons);
-  if ( (-1 == usage) ||
-       (-1 == selector) ||
-       (-1 == matching_type) )
+  tm = GTK_TREE_MODEL (
+    gtk_builder_get_object (builder, "edit_dialog_protocol_liststore"));
+  gtk_tree_model_get (tm, &iter, 1, &protocol, -1);
+  usage = get_selected_radio_value (builder, usage_buttons);
+  selector = get_selected_radio_value (builder, selector_buttons);
+  matching_type = get_selected_radio_value (builder, matching_type_buttons);
+  if ((-1 == usage) || (-1 == selector) || (-1 == matching_type))
   {
     GNUNET_break (0);
     return NULL;
   }
 
-  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW
-                                 (gtk_builder_get_object (builder,
-                                                          "edit_dialog_tlsa_value_textview")));
+  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (
+    gtk_builder_get_object (builder, "edit_dialog_tlsa_value_textview")));
 
   gtk_text_buffer_get_iter_at_offset (tb, &ti_start, 0);
   gtk_text_buffer_get_iter_at_offset (tb, &ti_end, -1);
 
-  value = gtk_text_buffer_get_text (tb,
-                                    &ti_start,
-                                    &ti_end,
-                                    FALSE);
+  value = gtk_text_buffer_get_text (tb, &ti_start, &ti_end, FALSE);
   GNUNET_asprintf (&result,
                    "%u %u %u %u %u %u %s",
                    protocol,
@@ -435,8 +402,7 @@ tlsa_store (void *cls,
  * @return #GNUNET_OK if there is a valid record value in the dialog
  */
 static int
-tlsa_validate (void *cls,
-               GtkBuilder *builder)
+tlsa_validate (void *cls, GtkBuilder *builder)
 {
   GtkComboBox *cb;
   GtkTreeIter iter;
@@ -452,42 +418,33 @@ tlsa_validate (void *cls,
   unsigned int selector;
   int err;
 
-  cb = GTK_COMBO_BOX (gtk_builder_get_object (builder,
-                                              "edit_dialog_protocol_combobox"));
-  if (! gtk_combo_box_get_active_iter (cb,
-                                       &iter))
+  cb = GTK_COMBO_BOX (
+    gtk_builder_get_object (builder, "edit_dialog_protocol_combobox"));
+  if (! gtk_combo_box_get_active_iter (cb, &iter))
   {
     return GNUNET_SYSERR;
   }
 
-  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW
-                                 (gtk_builder_get_object (builder,
-                                                          "edit_dialog_tlsa_value_textview")));
+  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (
+    gtk_builder_get_object (builder, "edit_dialog_tlsa_value_textview")));
   gtk_text_buffer_get_iter_at_offset (tb, &ti_start, 0);
   gtk_text_buffer_get_iter_at_offset (tb, &ti_end, -1);
-  value = gtk_text_buffer_get_text (tb,
-                                    &ti_start,
-                                    &ti_end,
-                                    FALSE);
+  value = gtk_text_buffer_get_text (tb, &ti_start, &ti_end, FALSE);
   if (0 == strlen (value))
     return GNUNET_SYSERR;
   {
     size_t slen = strlen (value);
     uint8_t bin[slen / 2];
 
-    if (slen / 2 !=
-        GNUNET_DNSPARSER_hex_to_bin (value,
-                                     bin))
+    if (slen / 2 != GNUNET_DNSPARSER_hex_to_bin (value, bin))
     {
       /* not hex */
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  _("Certificate value is not in hex...\n"));
+                  _ ("Certificate value is not in hex...\n"));
       return GNUNET_SYSERR;
     }
-    matching_type = get_selected_radio_value (builder,
-                                              matching_type_buttons);
-    selector = get_selected_radio_value (builder,
-                                       selector_buttons);
+    matching_type = get_selected_radio_value (builder, matching_type_buttons);
+    selector = get_selected_radio_value (builder, selector_buttons);
     switch (matching_type)
     {
     case 0: /* exact match */
@@ -496,49 +453,43 @@ tlsa_validate (void *cls,
       switch (selector)
       {
       case 0: /* full Cert */
-        if (GNUTLS_E_SUCCESS !=
-            (err = gnutls_x509_crt_init (&cert)))
+        if (GNUTLS_E_SUCCESS != (err = gnutls_x509_crt_init (&cert)))
         {
           GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                      _("Failed to initialize CERT: %s\n"),
+                      _ ("Failed to initialize CERT: %s\n"),
                       gnutls_strerror_name (err));
           ret = GNUNET_SYSERR;
           break;
         }
         if (GNUTLS_E_SUCCESS !=
-            (err = gnutls_x509_crt_import (cert,
-                                           &datum,
-                                           GNUTLS_X509_FMT_DER)))
-          {
-            GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                        _("Failed to parse CERT: %s\n"),
-                        gnutls_strerror_name (err));
-            ret = GNUNET_SYSERR;
-          }
+            (err = gnutls_x509_crt_import (cert, &datum, GNUTLS_X509_FMT_DER)))
+        {
+          GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                      _ ("Failed to parse CERT: %s\n"),
+                      gnutls_strerror_name (err));
+          ret = GNUNET_SYSERR;
+        }
         else
           ret = GNUNET_OK;
         gnutls_x509_crt_deinit (cert);
         break;
       case 1: /* subject public key only */
-        if (GNUTLS_E_SUCCESS !=
-            (err = gnutls_pubkey_init (&pk)))
+        if (GNUTLS_E_SUCCESS != (err = gnutls_pubkey_init (&pk)))
         {
           GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                      _("Failed to initialize PK: %s\n"),
+                      _ ("Failed to initialize PK: %s\n"),
                       gnutls_strerror_name (err));
           ret = GNUNET_SYSERR;
           break;
         }
         if (GNUTLS_E_SUCCESS !=
-            (err = gnutls_pubkey_import (pk,
-                                         &datum,
-                                         GNUTLS_X509_FMT_DER)))
-          {
-            GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                        _("Failed to parse PK: %s\n"),
-                        gnutls_strerror_name (err));
-            ret = GNUNET_SYSERR;
-          }
+            (err = gnutls_pubkey_import (pk, &datum, GNUTLS_X509_FMT_DER)))
+        {
+          GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
+                      _ ("Failed to parse PK: %s\n"),
+                      gnutls_strerror_name (err));
+          ret = GNUNET_SYSERR;
+        }
         else
           ret = GNUNET_OK;
         gnutls_pubkey_deinit (pk);
@@ -607,8 +558,7 @@ struct ImportContext
  * @param ic the import context
  */
 static void
-import_x509_certificate (gnutls_session_t session,
-                         struct ImportContext *ic)
+import_x509_certificate (gnutls_session_t session, struct ImportContext *ic)
 {
   GtkBuilder *builder = ic->builder;
   const gnutls_datum_t *cert_list;
@@ -622,14 +572,13 @@ import_x509_certificate (gnutls_session_t session,
   size_t bsize;
   char *hex;
   gnutls_datum_t datum;
-  uint8_t sha256[256/8];
-  uint8_t sha512[512/8];
+  uint8_t sha256[256 / 8];
+  uint8_t sha512[512 / 8];
   size_t ssize;
   GtkTextBuffer *tb;
   unsigned int i;
 
-  cert_list = gnutls_certificate_get_peers (session,
-                                            &cert_list_size);
+  cert_list = gnutls_certificate_get_peers (session, &cert_list_size);
   if (0 == cert_list_size)
   {
     /* is it possible to succeed with TLS handshake and have
@@ -638,10 +587,9 @@ import_x509_certificate (gnutls_session_t session,
     return;
   }
 
-  usage = get_selected_radio_value (builder,
-                                    usage_buttons);
+  usage = get_selected_radio_value (builder, usage_buttons);
   /* Find out which certificate we care about based on usage */
-  for (i=0;i<cert_list_size;i++)
+  for (i = 0; i < cert_list_size; i++)
   {
     char san[256];
     size_t san_size = sizeof (san);
@@ -652,9 +600,7 @@ import_x509_certificate (gnutls_session_t session,
 
     gnutls_x509_crt_init (&cert);
     if (GNUTLS_E_SUCCESS !=
-        gnutls_x509_crt_import (cert,
-                                &cert_list[i],
-                                GNUTLS_X509_FMT_DER))
+        gnutls_x509_crt_import (cert, &cert_list[i], GNUTLS_X509_FMT_DER))
     {
       GNUNET_break (0);
       gnutls_x509_crt_deinit (cert);
@@ -663,35 +609,27 @@ import_x509_certificate (gnutls_session_t session,
     if (1 == usage)
       break; /* RFC 6394: first certificate (i==0) is to be pinned */
     matches_dn = GNUNET_NO;
-    if ( (0 == gnutls_x509_crt_get_subject (cert,
-                                            &dn)) &&
-         (0 == gnutls_x509_dn_get_str (dn,
-                                       &str)) )
+    if ((0 == gnutls_x509_crt_get_subject (cert, &dn)) &&
+        (0 == gnutls_x509_dn_get_str (dn, &str)))
     {
       const char *cn;
 
-      cn = memmem (str.data,
-                   str.size,
-                   ",CN=",
-                   4);
-      if ( (NULL != cn) &&
-           ( ('\0' == cn[4 + strlen (ic->name)]) ||
-             (',' == cn[4 + strlen (ic->name)]) ) &&
-           (0 == strncasecmp (cn + 4,
-                              ic->name,
-                              strlen (ic->name))) )
+      cn = memmem (str.data, str.size, ",CN=", 4);
+      if ((NULL != cn) &&
+          (('\0' == cn[4 + strlen (ic->name)]) ||
+           (',' == cn[4 + strlen (ic->name)])) &&
+          (0 == strncasecmp (cn + 4, ic->name, strlen (ic->name))))
         matches_dn = GNUNET_YES;
     }
-    for (unsigned int seq=0;
-         GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE != gnutls_x509_crt_get_subject_alt_name (cert,
-                                                                                        seq,
-                                                                                        san,
-                                                                                        &san_size,
-                                                                                        &critical);
+    for (unsigned int seq = 0; GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE !=
+                               gnutls_x509_crt_get_subject_alt_name (cert,
+                                                                     seq,
+                                                                     san,
+                                                                     &san_size,
+                                                                     &critical);
          seq++)
     {
-      if (0 == strcasecmp (san,
-                           ic->name))
+      if (0 == strcasecmp (san, ic->name))
       {
         matches_dn = GNUNET_YES;
         break;
@@ -699,8 +637,8 @@ import_x509_certificate (gnutls_session_t session,
     }
     /* usage = 3: we want to match DN, otherwise we do NOT want to
        match DN */
-    if ( (GNUNET_NO == matches_dn)  ^ /* XOR */
-         (3 == usage) /* Domain issued certificate */ )
+    if ((GNUNET_NO == matches_dn) ^ /* XOR */
+        (3 == usage) /* Domain issued certificate */)
       break;
     gnutls_x509_crt_deinit (cert);
   }
@@ -713,17 +651,13 @@ import_x509_certificate (gnutls_session_t session,
     return;
   }
 
-  selector = get_selected_radio_value (builder,
-                                       selector_buttons);
+  selector = get_selected_radio_value (builder, selector_buttons);
   switch (selector)
   {
   case 0: /* full cert */
     bsize = sizeof (buf);
     if (GNUTLS_E_SUCCESS !=
-        gnutls_x509_crt_export (cert,
-                                GNUTLS_X509_FMT_DER,
-                                buf,
-                                &bsize))
+        gnutls_x509_crt_export (cert, GNUTLS_X509_FMT_DER, buf, &bsize))
     {
       GNUNET_break (0);
       gnutls_x509_crt_deinit (cert);
@@ -731,17 +665,13 @@ import_x509_certificate (gnutls_session_t session,
     }
     break;
   case 1: /* subject public key only */
-    if (GNUTLS_E_SUCCESS !=
-        gnutls_pubkey_init (&pk))
+    if (GNUTLS_E_SUCCESS != gnutls_pubkey_init (&pk))
     {
       GNUNET_break (0);
       gnutls_x509_crt_deinit (cert);
       return;
     }
-    if (GNUTLS_E_SUCCESS !=
-        gnutls_pubkey_import_x509 (pk,
-                                   cert,
-                                   0))
+    if (GNUTLS_E_SUCCESS != gnutls_pubkey_import_x509 (pk, cert, 0))
     {
       GNUNET_break (0);
       gnutls_x509_crt_deinit (cert);
@@ -750,10 +680,7 @@ import_x509_certificate (gnutls_session_t session,
     }
     bsize = sizeof (buf);
     if (GNUTLS_E_SUCCESS !=
-        gnutls_pubkey_export (pk,
-                              GNUTLS_X509_FMT_DER,
-                              buf,
-                              &bsize))
+        gnutls_pubkey_export (pk, GNUTLS_X509_FMT_DER, buf, &bsize))
     {
       GNUNET_break (0);
       gnutls_x509_crt_deinit (cert);
@@ -771,37 +698,29 @@ import_x509_certificate (gnutls_session_t session,
   /* 'buf' now contains 'bsize' bytes of the binary data to
      hash or store in the TLSA record; hash depending on
      user preferences. */
-  matching_type = get_selected_radio_value (builder,
-                                            matching_type_buttons);
+  matching_type = get_selected_radio_value (builder, matching_type_buttons);
   switch (matching_type)
   {
   case 0: /* exact match */
-    hex = GNUNET_DNSPARSER_bin_to_hex (buf,
-                                       bsize);
+    hex = GNUNET_DNSPARSER_bin_to_hex (buf, bsize);
     break;
   case 1: /* SHA-256 hash */
     datum.size = bsize;
     datum.data = (void *) buf;
     ssize = sizeof (sha256);
-    GNUNET_assert (GNUTLS_E_SUCCESS ==
-                   gnutls_fingerprint (GNUTLS_MAC_SHA256,
-                                       &datum,
-                                       sha256,
-                                       &ssize));
-    hex = GNUNET_DNSPARSER_bin_to_hex (sha256,
-                                       sizeof (sha256));
+    GNUNET_assert (
+      GNUTLS_E_SUCCESS ==
+      gnutls_fingerprint (GNUTLS_MAC_SHA256, &datum, sha256, &ssize));
+    hex = GNUNET_DNSPARSER_bin_to_hex (sha256, sizeof (sha256));
     break;
   case 2: /* SHA-512 hash */
     datum.size = bsize;
     datum.data = (void *) buf;
     ssize = sizeof (sha512);
-    GNUNET_assert (GNUTLS_E_SUCCESS ==
-                   gnutls_fingerprint (GNUTLS_MAC_SHA512,
-                                       &datum,
-                                       sha512,
-                                       &ssize));
-    hex = GNUNET_DNSPARSER_bin_to_hex (sha512,
-                                       sizeof (sha512));
+    GNUNET_assert (
+      GNUTLS_E_SUCCESS ==
+      gnutls_fingerprint (GNUTLS_MAC_SHA512, &datum, sha512, &ssize));
+    hex = GNUNET_DNSPARSER_bin_to_hex (sha512, sizeof (sha512));
     break;
   default:
     GNUNET_break (0);
@@ -809,12 +728,9 @@ import_x509_certificate (gnutls_session_t session,
   }
 
   /* Finally store 'hex' to the text buffer */
-  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW
-                                 (gtk_builder_get_object (builder,
-                                                          "edit_dialog_tlsa_value_textview")));
-  gtk_text_buffer_set_text (tb,
-                            hex,
-                            -1);
+  tb = gtk_text_view_get_buffer (GTK_TEXT_VIEW (
+    gtk_builder_get_object (builder, "edit_dialog_tlsa_value_textview")));
+  gtk_text_buffer_set_text (tb, hex, -1);
   GNUNET_free (hex);
 }
 
@@ -827,9 +743,7 @@ import_x509_certificate (gnutls_session_t session,
  * @param addrlen length of @a addr
  */
 static void
-import_address_cb (void *cls,
-                   const struct sockaddr *addr,
-                   socklen_t addrlen)
+import_address_cb (void *cls, const struct sockaddr *addr, socklen_t addrlen)
 {
   struct ImportContext *ic = cls;
   int pf;
@@ -848,15 +762,14 @@ import_address_cb (void *cls,
   {
     if (GNUNET_YES != ic->done)
       GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                  _("Name resolution for `%s' failed\n"),
+                  _ ("Name resolution for `%s' failed\n"),
                   ic->name);
     GNUNET_free (ic->name);
     GNUNET_free (ic);
     return;
   }
-  port = gtk_spin_button_get_value
-    (GTK_SPIN_BUTTON (gtk_builder_get_object (ic->builder,
-                                              "edit_dialog_port_spinbutton")));
+  port = gtk_spin_button_get_value (GTK_SPIN_BUTTON (
+    gtk_builder_get_object (ic->builder, "edit_dialog_port_spinbutton")));
   switch (addr->sa_family)
   {
   case AF_INET:
@@ -873,30 +786,23 @@ import_address_cb (void *cls,
     break;
   default:
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("Unsupported address family %d\n"),
+                _ ("Unsupported address family %d\n"),
                 addr->sa_family);
     return;
   }
-  ic->sock = GNUNET_NETWORK_socket_create (pf,
-                                           SOCK_STREAM,
-                                           0);
+  ic->sock = GNUNET_NETWORK_socket_create (pf, SOCK_STREAM, 0);
   if (NULL == ic->sock)
   {
-    GNUNET_log_strerror (GNUNET_ERROR_TYPE_WARNING,
-                         "socket");
+    GNUNET_log_strerror (GNUNET_ERROR_TYPE_WARNING, "socket");
     return;
   }
   GNUNET_break (GNUNET_OK ==
-                GNUNET_NETWORK_socket_set_blocking (ic->sock,
-                                                    GNUNET_YES));
-  if ( (GNUNET_OK !=
-        GNUNET_NETWORK_socket_connect (ic->sock,
-                                       a,
-                                       addrlen)) &&
-       (EINPROGRESS != errno) )
+                GNUNET_NETWORK_socket_set_blocking (ic->sock, GNUNET_YES));
+  if ((GNUNET_OK != GNUNET_NETWORK_socket_connect (ic->sock, a, addrlen)) &&
+      (EINPROGRESS != errno))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
-                _("Failed to connect to target address `%s': %s\n"),
+                _ ("Failed to connect to target address `%s': %s\n"),
                 GNUNET_a2s (addr, addrlen),
                 STRERROR (errno));
     GNUNET_NETWORK_socket_close (ic->sock);
@@ -905,8 +811,7 @@ import_address_cb (void *cls,
 
   /* initialize TLS session */
   gnutls_init (&session, GNUTLS_CLIENT);
-  gnutls_session_set_ptr (session,
-                          ic);
+  gnutls_session_set_ptr (session, ic);
   gnutls_server_name_set (session,
                           GNUTLS_NAME_DNS,
                           ic->name,
@@ -916,23 +821,17 @@ import_address_cb (void *cls,
   /* Use default priorities */
   gnutls_certificate_allocate_credentials (&xcred);
   if (GNUTLS_E_SUCCESS !=
-      (ret = gnutls_priority_set_direct (session,
-                                         "PERFORMANCE",
-                                         NULL)))
+      (ret = gnutls_priority_set_direct (session, "PERFORMANCE", NULL)))
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("Failed to initialize cipher suite: %s\n"),
+                _ ("Failed to initialize cipher suite: %s\n"),
                 gnutls_strerror (ret));
     goto cleanup;
   }
   /* put the x509 credentials to the current session */
-  gnutls_credentials_set (session,
-                          GNUTLS_CRD_CERTIFICATE,
-                          xcred);
-  gnutls_transport_set_int (session,
-                            GNUNET_NETWORK_get_fd (ic->sock));
-  gnutls_handshake_set_timeout (session,
-                                2000 /* 2s */);
+  gnutls_credentials_set (session, GNUTLS_CRD_CERTIFICATE, xcred);
+  gnutls_transport_set_int (session, GNUNET_NETWORK_get_fd (ic->sock));
+  gnutls_handshake_set_timeout (session, 2000 /* 2s */);
 
   /* TODO: do this in event loop, with insensitive GUI,
      with possibly higher timeout ... */
@@ -940,8 +839,7 @@ import_address_cb (void *cls,
   do
   {
     ret = gnutls_handshake (session);
-  }
-  while ( (ret < 0) && (0 == gnutls_error_is_fatal (ret)) );
+  } while ((ret < 0) && (0 == gnutls_error_is_fatal (ret)));
 
   /* finally, access the certificate */
   if (GNUTLS_E_SUCCESS == ret)
@@ -951,30 +849,28 @@ import_address_cb (void *cls,
     {
     case GNUTLS_CRT_UNKNOWN:
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  _("Server certificate type not supported\n"));
+                  _ ("Server certificate type not supported\n"));
       break;
     case GNUTLS_CRT_X509:
-      import_x509_certificate (session,
-                               ic);
+      import_x509_certificate (session, ic);
       break;
     default:
       GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                  _("Server certificate type not supported\n"));
+                  _ ("Server certificate type not supported\n"));
       break;
     }
   }
   else
   {
     GNUNET_log (GNUNET_ERROR_TYPE_ERROR,
-                _("TLS handshake failed: %s\n"),
+                _ ("TLS handshake failed: %s\n"),
                 gnutls_strerror (ret));
   }
   gnutls_bye (session, GNUTLS_SHUT_RDWR);
   ic->done = GNUNET_YES;
 
- cleanup:
-  GNUNET_break (GNUNET_OK ==
-                GNUNET_NETWORK_socket_close (ic->sock));
+cleanup:
+  GNUNET_break (GNUNET_OK == GNUNET_NETWORK_socket_close (ic->sock));
   gnutls_deinit (session);
   gnutls_certificate_free_credentials (xcred);
 }
@@ -988,21 +884,18 @@ import_address_cb (void *cls,
  * @param user_data the plugin environment
  */
 static void
-tlsa_import_button_clicked_cb (GtkButton *button,
-                               gpointer user_data)
+tlsa_import_button_clicked_cb (GtkButton *button, gpointer user_data)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *edc = user_data;
   struct ImportContext *ic;
   const gchar *name;
   GtkWidget *entry;
 
-  entry = GTK_WIDGET (gtk_builder_get_object (edc->builder,
-                                              "edit_dialog_tlsa_import_entry"));
-  name = gtk_editable_get_chars (GTK_EDITABLE (entry),
-                                 0, -1);
-  if ( (NULL == name) ||
-       (0 == strlen (name)) ||
-       (GNUNET_OK != GNUNET_DNSPARSER_check_name (name)) )
+  entry = GTK_WIDGET (
+    gtk_builder_get_object (edc->builder, "edit_dialog_tlsa_import_entry"));
+  name = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+  if ((NULL == name) || (0 == strlen (name)) ||
+      (GNUNET_OK != GNUNET_DNSPARSER_check_name (name)))
   {
     /* import button should not have been sensitive */
     GNUNET_break (0);
@@ -1035,13 +928,11 @@ edit_dialog_tlsa_import_entry_changed_cb (GtkEditable *entry,
   gboolean sens;
   GtkWidget *button;
 
-  button = GTK_WIDGET (gtk_builder_get_object (edc->builder,
-                                               "edit_dialog_tlsa_import_button"));
-  preedit = gtk_editable_get_chars (GTK_EDITABLE (entry),
-                                    0, -1);
-  if ( (NULL == preedit) ||
-       (0 == strlen (preedit)) ||
-       (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)) )
+  button = GTK_WIDGET (
+    gtk_builder_get_object (edc->builder, "edit_dialog_tlsa_import_button"));
+  preedit = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+  if ((NULL == preedit) || (0 == strlen (preedit)) ||
+      (GNUNET_OK != GNUNET_DNSPARSER_check_name (preedit)))
     sens = FALSE;
   else
     sens = TRUE;
@@ -1060,24 +951,23 @@ libgnunet_plugin_gtk_namestore_tlsa_init (void *cls)
 {
   struct GNUNET_GTK_NAMESTORE_PluginEnvironment *env = cls;
   struct GNUNET_GTK_NAMESTORE_PluginFunctions *plugin;
-  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] = {
-    { "tlsa_value_textbuffer_changed_cb",
-      G_CALLBACK (tlsa_value_textbuffer_changed_cb) },
-    { "edit_dialog_tlsa_selector_radiobutton_toggled_cb",
-      G_CALLBACK (edit_dialog_tlsa_selector_radiobutton_toggled_cb) },
-    { "edit_dialog_tlsa_usage_radiobutton_toggled_cb",
-      G_CALLBACK (edit_dialog_tlsa_usage_radiobutton_toggled_cb) },
-    { "edit_dialog_tlsa_matching_type_radiobutton_toggled_cb",
-      G_CALLBACK (edit_dialog_tlsa_matching_type_radiobutton_toggled_cb) },
-    { "tlsa_import_button_clicked_cb",
-      G_CALLBACK (tlsa_import_button_clicked_cb) },
-    { "edit_dialog_tlsa_import_entry_changed_cb",
-      G_CALLBACK (edit_dialog_tlsa_import_entry_changed_cb) },
-    /* generic CBs */
-    { "edit_dialog_protocol_combobox_changed_cb",
-      G_CALLBACK (edit_dialog_protocol_combobox_changed_cb) },
-    { NULL, NULL }
-  };
+  static struct GNUNET_GTK_NAMESTORE_Symbol symbols[] =
+    {{"tlsa_value_textbuffer_changed_cb",
+      G_CALLBACK (tlsa_value_textbuffer_changed_cb)},
+     {"edit_dialog_tlsa_selector_radiobutton_toggled_cb",
+      G_CALLBACK (edit_dialog_tlsa_selector_radiobutton_toggled_cb)},
+     {"edit_dialog_tlsa_usage_radiobutton_toggled_cb",
+      G_CALLBACK (edit_dialog_tlsa_usage_radiobutton_toggled_cb)},
+     {"edit_dialog_tlsa_matching_type_radiobutton_toggled_cb",
+      G_CALLBACK (edit_dialog_tlsa_matching_type_radiobutton_toggled_cb)},
+     {"tlsa_import_button_clicked_cb",
+      G_CALLBACK (tlsa_import_button_clicked_cb)},
+     {"edit_dialog_tlsa_import_entry_changed_cb",
+      G_CALLBACK (edit_dialog_tlsa_import_entry_changed_cb)},
+     /* generic CBs */
+     {"edit_dialog_protocol_combobox_changed_cb",
+      G_CALLBACK (edit_dialog_protocol_combobox_changed_cb)},
+     {NULL, NULL}};
 
   gnutls_global_init ();
   plugin = GNUNET_new (struct GNUNET_GTK_NAMESTORE_PluginFunctions);
